
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%
%                          ESTIMATION                         %
%                       Learning Model              %
%            Setup : Matrices voor Random nrs, Train Draws    %      
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++%

clc;            % clear command window
clear all;      % clear workspace

parpool;

np=4587; % number of households  
n=747496; % number of occasions X alternatives
nv=24; % number of variables (per alternative) 
ni=8; % number of alternatives
nres=n/ni; % total number of trips across households 
ncoefhet=12; %total heterogeneous pars
ncoef=47;% total number of entries in b0 (means+Sds+homogeneous pars)
nvtot=24;
ncop=4;%total number of copulas

% load number of trips per household 
times=load ('\PCrisps_times.dat');
purchases= load ('\PCrisps_purchases.dat');
times=reshape(times,np,1);
purchases=reshape(purchases,np,1);

% load purchase data and explanatory vars 
x= load('\PAN_WK_SH_BR26112015_sel_ho_ad_R.dat');
%columns in x:
%1Panelist 2Vol_sls_b 3Vol_gift_b 4initialization_period_b 5Brand_bought 6Brand_gift 
%7rel_avg_price_per_ml_b_to_c 8Distr_retailer_b 9assort_width_b 10SOV_AdStock80_b_to_c  
%11H 12G 13F 14E 15D 16C 17B 18A 19holdout_sample 20Date_of_purchase  
%21price_STAR 22nr_newflav_SKUs_since_last_bg 23nr_newprod_SKUs_since_last_bg 24nr_newpack_SKUs_since_last_bg

x=reshape(x,n,nvtot);

ah=load('\ad_signals.dat');
ah=reshape(ah,n,2);

x=horzcat(x,ah);

%% Adjust

% create correct quantity correction (put in place of date)
x(:,20)=(x(:,2)+x(:,3))/104;
% create correct quantity correction adv
x(:,26)=x(:,26)/71905410;

nr_new_correct= load('\nr_new_Skus_correct.dat');
%flavor
x(:,21)=x(:,21).*nr_new_correct;
% Redefine NP intros since last as fraction of assortment
x(:,21)=x(:,21)./x(:,9);
%product
x(:,23)=x(:,23).*nr_new_correct;
% Redefine NP intros since last as fraction of assortment
x(:,23)=x(:,23)./x(:,9);



% rescale assortment variable 
x(:,9)=x(:,9)/100;

%add copulas price distr asso and adv
cop=load('\copulas.dat');

x=horzcat(x,cop);

x=(reshape(x(1:n,[4:18 20 23 24 25 26 27:30])',nv*ni,n/ni))'; 
% X matrix is (nres X ni*nv)
%1initialization_period_b 2Brand_bought 3Brand_gift 
%4rel_avg_price_per_ml_b_to_c 5Distr_retailer_b 6assort_width_b 7SOV_AdStock80_b_to_c  
%8H 9G 10F 11E 12D 13C 14B 15A 16cons quan  
%17nr_newprod_SKUs_since_last_bg 18nr_newpack_SKUs_since_last_bg
%19ad signal 20amount spent 21price* 22distr* 23assort* 24adv*


%% Draws
% number of draws 
nrep=100; 
seed1=46;
rng(seed1); % starts the random number generator at SEED1
err2=randn(n/ni,nrep);
seed2=80;
err1=makedraws_hh_R(nrep,np,ncoefhet,seed2);
seed3=24;
err3=makedraws_hh_R(nrep,np,ni,seed3); % extra draws for mixing distribution brand quality change type 1; ni x nrep x np
err3(5,:,:)=zeros(1,nrep,np); %no draws for brand 5 which has no innovations
err3(1,:,:)=zeros(1,nrep,np); %no draws for brand 1 which has no innovations
seed4=66;
err4=makedraws_hh_R(nrep,np,ni,seed4); % extra draws for mixing distribution brand quality change type 2; ni x nrep x np
err4(5,:,:)=zeros(1,nrep,np); %no draws for brand 5 which has no innovations 
err4(1,:,:)=zeros(1,nrep,np); %no draws for brand 1 which has no innovations 
seed5=77;
rng(seed5);
err5=randn(n/ni,nrep); % random number draws for advertising signals


% rows in matrix = total number of household-trips 					 
% columns are variables pertaining to all choice options


%% Estimate



b0 =[-1.0209;-0.2083;-1.3893;1.3814;1.1732;-1.4077;-1.2599;-0.9916;...
    -0.7066;1.4781;-0.8504;-0.8829;-0.1888;-1.2096;-1.072;0.8661;...
    -0.0057;0.9284;0.0288;0.8356;0.319;0.2472;0.1397;0.5242;1.3811;...
    2.5888;1.5599;1.4579;-0.5227;-1.739;-0.8979;0.0198;1.6148;-1.135;...
    32.4923;1.2388;1.3149;1.2172;1.1329;1.2398;1.0737;0.9407;1.0272;...
    0.1605;-0.0121;-0.2337;-0.4011];
% starting values for parameters */

names={'lnrisk' 'risk_SD' 'price' 'priceSD' 'dist' 'distSD' ...
'H' 'HSD' 'G' 'GSD' 'F' 'FSD'  'D'  'DSD'  ...
'E'  'ESD' 'C' 'CSD'  'B' 'BSD'  'asso' 'assSD' ...
'adv' 'advSD' 'lnsigv'  'lninitdt1' 'lninitdt2'  ...
'ddelq2G' 'ddelq3F' 'ddelq4E' ...
'ddelq6C' 'ddelq7B' 'delt1' 'delt2' ...
'lnsigv_adv' ...
'lninit1H' 'lninit2G' 'lninit3F' 'lninit4E' ...
'lninit5D' 'lninit6C' 'lninit7B' 'lninit8A' ...
'pricestar' 'distrstar' 'assostar' 'advstar'}; 

% Estimation:
% estimation options:

options	= optimset('Maxiter',1000,'MaxFunEvals',150000,'LargeScale','off','GradObj', ...
    'off','TolFun',1e-07,...
'TolCon',1e-07,'Display','iter','OutputFcn',@Output);


% optimization procedure:
[b,fval,exitflag,output,grad,hessian] = ...
fminunc(@Estimation_function_M2,b0,options,x,err1,err2,err3,err4,err5, ...
times,np,nv,ni,ncoefhet,ncop,nrep);

% standard errors:
se_b    = sqrt(diag(inv(hessian)));
cov_b=inv(hessian);

% Print output:
disp('-----------------------------------------------------------------------');
fprintf('%-60s %10.0f\n', 'Number of iterations:', output.iterations);
fprintf('%-60s %10.4f\n', 'Value of the log-likelihood function at convergence: ', (-fval));
disp(' ');
disp('-----------------------------------------------------------------------');
disp('                                            value       s.e.     t-stat');
disp('-----------------------------------------------------------------------');
for r=1:(size(names,2));
    fprintf('%-38s %10.4f %10.4f %10.4f\n', names{1,r}, [b(r,1),se_b(r,1),b(r,1)./se_b(r,1)]);
end
disp('-----------------------------------------------------------------------');

