﻿/* folder with yearly purchase data for CN PCrisps in SAS format */
libname dataCNp '\CN 2011-2015';	
/*folder for any output datasets*/
libname idataCN '\Potato Crisps';

/*MERGE PURCHASE FILES Potato Crisps AND BARCODE FILE*/
data CatDef_PCrisps;
set dataCNp.Category_definitions_cn_20112014;
where BG_Category_name='Potato Crisps';
proc sort data=CatDef_PCrisps;by Barcode Reference_code;
proc sort data=dataCNp.Barcode_allattributes;by Barcode Reference_code;
data BC_CatDef_PCrisps;
merge CatDef_PCrisps(in=a) dataCNp.Barcode_allattributes(in=b);by Barcode Reference_code;if a=b;run;
proc sort data=BC_CatDef_PCrisps;by Barcode Reference_code;
%macro yr (year=);
proc sort data=dataCNp.Purchase_&year;by Barcode Reference_code;
data Purchase_&year._PCrisps_bc;
merge dataCNp.Purchase_&year(in=a) BC_CatDef_PCrisps(in=b);by Barcode Reference_code;if a=b;
Total_volume_sales_check=Total_unit_sales*Volume_per_unit;run;
%mend yr;
%yr (year=2011) %yr (year=2012) %yr (year=2013) %yr (year=2014);

data purchase_20112014_PCrisps_BC;
set purchase_2011_PCrisps_bc purchase_2012_PCrisps_bc purchase_2013_PCrisps_bc purchase_2014_PCrisps_bc;run;

/*MERGE PANELIST&SHOPCODE INFO*/
proc sort data=Purchase_20112014_PCrisps_bc;by panelist quarter;
proc sort data=dataCNp.panelist;by panelist quarter;
data pur_p;
merge Purchase_20112014_PCrisps_bc(in=a) dataCNp.panelist(in=b);by panelist quarter;if a;
proc sort data=pur_p;by shopcode;
proc sort data=dataCNp.shopcode;by shopcode;
data idatacn.pur_PCrisps_allinfo_20112014;
merge pur_p(in=a) dataCNp.shopcode(in=b);by shopcode;if a;
	month=month(Date_of_purchase);
	year=year(Date_of_purchase);
run;

/*start building a dataset on which MNL model can be ran*/
/*start dataset of years X weeks X shoptripnr X panelists X 8 brands*/
data PUR_ALLINFO_20112014;
set idataCN.pur_PCrisps_allinfo_20112014;
week=week(Date_of_purchase , 'w');
if Barcode_description NE '';
if Income_class>11 then high_income=1;
if Income_class<=11 then high_income=0;
if Income_class notin (.,1);
price_per_ml=Total_value_sales/Total_volume_sales;
price_per_unit=Total_value_sales/Total_unit_sales;
if Banner_name NE '';
var=1;
run;

/*check how week variable is created*/
data yearweekdate;
set PUR_ALLINFO_20112014;
keep year week date_of_purchase;
proc sort data=yearweekdate nodup;by year week date_of_purchase;run;

/*check number of days in a week*/
proc sql;
	create table nrdaysinaweek as
	select year, week, count(date_of_purchase) as nr_days
	from yearweekdate
	group by year, week;
quit;

/*artificially create correct week numbers so that every week has 7 days*/
data PUR_ALLINFO_20112014;
set PUR_ALLINFO_20112014;
if year=2010 then delete;/*we don't want to take 2010 into account*/
if year=2011 and week=0 then delete;/*week 20110 only has 2 days*/
if year=2012 and week=0 then do year=2011;week=52;end;/*week 201152 has only 6 days and week 201200 only has 1 day*/
if year=2013 and week=0 then do year=2012;week=53;end;/*week 201253 has only 1 day and week 201300 only has 6 days*/
if year=2014 and week=0 then do year=2013;week=52;end;/*week 201352 has only 2 days and week 201400 only has 5 days*/
if year=2014 and week=51 then delete;/*week 201451 only has 5 days*/
run;
/*create a base dataset to which all to-be-calculated measures will be merged*/

/*prepare for innovation and and assort width: add period column*/
data PUR_ALLINFO_20112014;
set PUR_ALLINFO_20112014;
if week<=4 then period=(compress((put(year, 4.))||'01'))*1;
if 5<=week<=8 then period=(compress((put(year, 4.))||'02'))*1;
if 9<=week<=12 then period=(compress((put(year, 4.))||'03'))*1;
if 13<=week<=16 then period=(compress((put(year, 4.))||'04'))*1;
if 17<=week<=20 then period=(compress((put(year, 4.))||'05'))*1;
if 21<=week<=24 then period=(compress((put(year, 4.))||'06'))*1;
if 25<=week<=28 then period=(compress((put(year, 4.))||'07'))*1;
if 29<=week<=32 then period=(compress((put(year, 4.))||'08'))*1;
if 33<=week<=36 then period=(compress((put(year, 4.))||'09'))*1;
if 37<=week<=40 then period=(compress((put(year, 4.))||'10'))*1;
if 41<=week<=44 then period=(compress((put(year, 4.))||'11'))*1;
if 45<=week<=48 then period=(compress((put(year, 4.))||'12'))*1;
if 49<=week then period=(compress((put(year, 4.))||'13'))*1;run;



/* 1) create a list of panelists X consumed (!) weeks X 'shoptrip' 
(i.e., those weeks in which they really consumed (so bought+received) PCrisps)*/
data panelist_week_date_shop;
set PUR_ALLINFO_20112014;
keep Panelist year week Date_of_purchase Shopcode var;run;
proc sort data=panelist_week_date_shop nodup;
by Panelist year week Date_of_purchase Shopcode var;run;
data panelist_week_shoptrip;
  set panelist_week_date_shop;
  shoptrip + 1;
  by Panelist year week Date_of_purchase Shopcode var;
  if first.Panelist OR first.year OR first.week then shoptrip = 1;
run;

/*check max number of ACTUAL shoptrips in a week*/
data panelist_week_date_shop_a;
set PUR_ALLINFO_20112014;
if Local_store_type notin ('GIFT','WORK UNIT');
keep Panelist year week Date_of_purchase Shopcode var;run;
proc sort data=panelist_week_date_shop_a nodup;
by Panelist year week Date_of_purchase Shopcode var;run;
data panelist_week_shoptrip_a;
  set panelist_week_date_shop_a;
  shoptrip + 1;
  by Panelist year week Date_of_purchase Shopcode var;
  if first.Panelist OR first.year OR first.week then shoptrip = 1;
run;
proc freq data=panelist_week_shoptrip_a;tables shoptrip;run; 

/*merge 'shoptrip' column to base dataset*/
proc sort data=PUR_ALLINFO_20112014;by Panelist year week Date_of_purchase Shopcode var;
proc sort data=panelist_week_shoptrip;by Panelist year week Date_of_purchase Shopcode var;
data PUR_ALLINFO_20112014;
merge PUR_ALLINFO_20112014 panelist_week_shoptrip;by Panelist year week Date_of_purchase Shopcode var;
run;


/* 2) create a list of brands*/
data pur_PCrisps_bought;
set idataCN.pur_PCrisps_allinfo_20112014;
if Local_store_type notin ('GIFT','WORK UNIT');
/*market shares per year*/
%macro yr (year=);
data pur_PCrisps_bought_&year;
set pur_PCrisps_bought;
where year=&year;
proc sql;
	create table vol_sls_per_br as
	select BG_category_name, brand, brand_latinname, sum(total_volume_sales) as vol_sls_per_br
	from pur_PCrisps_bought_&year
	group by BG_category_name, brand, brand_latinname;
quit;
proc sql;
	create table vol_sls_per_cat as
	select BG_category_name, sum(total_volume_sales) as vol_sls_per_cat
	from pur_PCrisps_bought_&year
	group by BG_category_name;
quit;
proc sort data=vol_sls_per_br;by BG_category_name;
proc sort data=vol_sls_per_cat;by BG_category_name;
data idataCN.PCrisps_ms_cat_br_&year;
merge vol_sls_per_br vol_sls_per_cat;by BG_category_name;
ms_vol_br=vol_sls_per_br/vol_sls_per_cat;
year=&year;
proc sort data=idataCN.PCrisps_ms_cat_br_&year;by descending ms_vol_br;run;
%mend yr;
%yr (year=2011);
data top8_brands;
set idataCN.PCrisps_ms_cat_br_2011; 
where Brand_latinname in ("");/*not allowed to share brand names*/
keep Brand Brand_latinname;run;
proc sort data=top8_brands nodup;by Brand_latinname;
data brands;
set top8_brands;
n=_N_;
if n<10 then BrandNumber=compress(('Brand'||'0'||(put(n,2.))));
	else BrandNumber=compress(('Brand'||(put(n,2.))));
drop n;
var=1;
run;

 
/* 3) merge brand dummies and numbers to PUR_ALLINFO_20112014 and create extra column for shoptrips with multiple brands bought*/
proc sort data=PUR_ALLINFO_20112014;by Brand Brand_latinname;
proc sort data=brands;by Brand Brand_latinname;
data PUR_ALLINFO_20112014;
merge PUR_ALLINFO_20112014(in=a) brands;by Brand Brand_latinname;if a;
run;
proc sql;
	create table brand_bought_or_gift as
	select panelist, year, week, shoptrip, BrandNumber, var,
		sum(Total_volume_sales) as Vol_sls_or_gift_b,
		sum(Total_value_sales) as Val_sls_or_gift_b
	from PUR_ALLINFO_20112014 
	group by Panelist, year, week, shoptrip, BrandNumber, var;
quit;
data brand_bought_or_gift;
  set brand_bought_or_gift;
  brand_in_shoptrip + 1;
  by Panelist year week shoptrip;
  if first.Panelist OR first.year OR first.week OR first.shoptrip then brand_in_shoptrip = 1;
run;

/*check max number of brands in ACTUAL shoptrips in a week*/
data panelist_week_date_shop_b;
set PUR_ALLINFO_20112014;
if Local_store_type notin ('GIFT','WORK UNIT');
keep Panelist year week shoptrip BrandNumber Date_of_purchase Shopcode var;run;
proc sort data=panelist_week_date_shop_b nodup;
by Panelist year week shoptrip BrandNumber Date_of_purchase Shopcode var;run;
data panelist_week_shoptrip_a1;
  set panelist_week_date_shop_b;
  brand_in_shoptrip + 1;
  by Panelist year week shoptrip Date_of_purchase Shopcode var;
  if first.Panelist OR first.year OR first.week OR first.shoptrip then brand_in_shoptrip = 1;
run;
proc freq data=panelist_week_shoptrip_a1;tables brand_in_shoptrip;run; 

/*merge 'brand_in_shoptrip' column to base dataset*/
proc sort data=PUR_ALLINFO_20112014;by Panelist year week shoptrip BrandNumber;
proc sort data=brand_bought_or_gift;by Panelist year week shoptrip BrandNumber;
data PUR_ALLINFO_20112014;
merge PUR_ALLINFO_20112014(in=a) brand_bought_or_gift;by Panelist year week shoptrip BrandNumber;if a;
year_c=put(year, 4.);
if week<10 then week_c=(compress('0'||week));
	else week_c=compress(week);
if shoptrip<10 then shoptrip_c=(compress('0'||shoptrip));
	else shoptrip_c=compress(shoptrip);
if brand_in_shoptrip<10 then brand_in_shoptrip_c=(compress('0'||brand_in_shoptrip));
	else brand_in_shoptrip_c=compress(brand_in_shoptrip);
yearweekbrandinshoptrip=(compress(year_c||week_c||shoptrip_c||brand_in_shoptrip_c));
run;




/* 4) base set of panelists X consumed weeks X shoptrip X brand_in_shoptrip X brands*/
data panelist_week_shoptrip_b;
set PUR_ALLINFO_20112014;
where BrandNumber NE '';/*only select top8*/
keep Panelist Date_of_purchase year week shoptrip brand_in_shoptrip var year_c week_c shoptrip_c brand_in_shoptrip_c yearweekbrandinshoptrip;
proc sort data=panelist_week_shoptrip_b nodup;
by Panelist Date_of_purchase year week shoptrip brand_in_shoptrip var year_c week_c shoptrip_c brand_in_shoptrip_c yearweekbrandinshoptrip;run;

proc sql;
	create table panelist_week_shoptrip_b_brands as
	select *
	from panelist_week_shoptrip_b as a, brands as b
	where a.var=b.var;
quit;

/*add period column*/
data panelist_week_shoptrip_b_brands;
set panelist_week_shoptrip_b_brands;
if week<=4 then period=(compress((put(year, 4.))||'01'))*1;
if 5<=week<=8 then period=(compress((put(year, 4.))||'02'))*1;
if 9<=week<=12 then period=(compress((put(year, 4.))||'03'))*1;
if 13<=week<=16 then period=(compress((put(year, 4.))||'04'))*1;
if 17<=week<=20 then period=(compress((put(year, 4.))||'05'))*1;
if 21<=week<=24 then period=(compress((put(year, 4.))||'06'))*1;
if 25<=week<=28 then period=(compress((put(year, 4.))||'07'))*1;
if 29<=week<=32 then period=(compress((put(year, 4.))||'08'))*1;
if 33<=week<=36 then period=(compress((put(year, 4.))||'09'))*1;
if 37<=week<=40 then period=(compress((put(year, 4.))||'10'))*1;
if 41<=week<=44 then period=(compress((put(year, 4.))||'11'))*1;
if 45<=week<=48 then period=(compress((put(year, 4.))||'12'))*1;
if 49<=week then period=(compress((put(year, 4.))||'13'))*1;run;









/******variables******/


/*** 1) amount bought***/
data PUR_ALLINFO_20112014_b;
set PUR_ALLINFO_20112014;
if Local_store_type notin ('GIFT','WORK UNIT');run;
	/***brand***/
proc sql;
	create table brand_bought as
	select panelist, year, week, shoptrip, brand_in_shoptrip, BrandNumber, 
		sum(Total_volume_sales) as Vol_sls_b,
		sum(Total_value_sales) as Val_sls_b
	from PUR_ALLINFO_20112014_b 
	group by Panelist, year, week, shoptrip, brand_in_shoptrip, BrandNumber;
quit;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_b_brands;by Panelist year week shoptrip brand_in_shoptrip BrandNumber;
proc sort data=brand_bought;by Panelist year week shoptrip brand_in_shoptrip BrandNumber;
data panelist_week_shoptrip_brands_1a;
merge panelist_week_shoptrip_b_brands(in=a) brand_bought(in=b);by Panelist year week shoptrip brand_in_shoptrip BrandNumber;if a;
if b=1 then Brand_bought=1;
if b NE 1 then Brand_bought=0;
if Vol_sls_b=. then Vol_sls_b=0;
if Val_sls_b=. then Val_sls_b=0;run; 
	
	/***PCrisps***/
proc sql;
	create table PCrisps_bought as
	select panelist, year, week, shoptrip, brand_in_shoptrip,
		sum(Total_volume_sales) as Vol_sls_c,
		sum(Total_value_sales) as Val_sls_c
	from PUR_ALLINFO_20112014_b 
	group by Panelist, year, week, shoptrip, brand_in_shoptrip;
quit;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_1b;by Panelist year week shoptrip brand_in_shoptrip;
proc sort data=PCrisps_bought;by Panelist year week shoptrip brand_in_shoptrip;
data panelist_week_shoptrip_brands_1b;
merge panelist_week_shoptrip_brands_1a(in=a) PCrisps_bought(in=b);by Panelist year week shoptrip brand_in_shoptrip;if a;
if b=1 then PCrisps_bought=1;
if b NE 1 then PCrisps_bought=0;
if Vol_sls_c=. then Vol_sls_c=0;
if Val_sls_c=. then Val_sls_c=0;run; 




/*** 2) amount received as gift***/
data PUR_ALLINFO_20112014_g;
set PUR_ALLINFO_20112014;
if Local_store_type in ('GIFT','WORK UNIT');run;
	/***brand***/
proc sql;
	create table brand_rec_as_gift as
	select panelist, year, week, shoptrip, brand_in_shoptrip, BrandNumber, 
		sum(Total_volume_sales) as Vol_gift_b
	from PUR_ALLINFO_20112014_g
	group by Panelist, year, week, shoptrip, brand_in_shoptrip, BrandNumber;
quit;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_1b;by Panelist year week shoptrip brand_in_shoptrip BrandNumber;
proc sort data=brand_rec_as_gift;by Panelist year week shoptrip brand_in_shoptrip BrandNumber;
data panelist_week_shoptrip_brands_2a;
merge panelist_week_shoptrip_brands_1b(in=a) brand_rec_as_gift(in=b);by Panelist year week shoptrip brand_in_shoptrip BrandNumber;if a;
if b=1 then Brand_gift=1;
if b NE 1 then Brand_gift=0;
if Vol_gift_b=. then Vol_gift_b=0;run; 
	/***PCrisps***/
proc sql;
	create table PCrisps_rec_as_gift as
	select panelist, year, week, shoptrip, brand_in_shoptrip,
		sum(Total_volume_sales) as Vol_gift_c
	from PUR_ALLINFO_20112014_g
	group by Panelist, year, week, shoptrip, brand_in_shoptrip;
quit;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_2a;by Panelist year week shoptrip brand_in_shoptrip;
proc sort data=PCrisps_rec_as_gift;by Panelist year week shoptrip brand_in_shoptrip;
data panelist_week_shoptrip_brands_2b;
merge panelist_week_shoptrip_brands_2a(in=a) PCrisps_rec_as_gift(in=b);by Panelist year week shoptrip brand_in_shoptrip;if a;
if b=1 then PCrisps_Gift=1;
if b NE 1 then PCrisps_Gift=0;
if Vol_gift_c=. then Vol_gift_c=0;run;




/*** 3) prices***/
	/***brand***/
proc sql;													
	create table brand_prices as
	select year, week, BrandNumber,
		mean(price_per_ml) as avg_price_per_ml_b, std(price_per_ml) as sd_price_per_ml_b,
		mean(price_per_unit) as avg_price_per_unit_b, std(price_per_unit) as sd_price_per_unit_b
	from PUR_ALLINFO_20112014_b
	group by year, week, BrandNumber;
quit;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_2c;by year week BrandNumber;
proc sort data=brand_prices;by year week BrandNumber;
data panelist_week_shoptrip_brands_3a;
merge panelist_week_shoptrip_brands_2b(in=a) brand_prices(in=b);by year week BrandNumber;if a;
run;
	/***PCrisps***/
proc sql;													
	create table PCrisps_prices as
	select year, week, 
		mean(price_per_ml) as avg_price_per_ml_c, std(price_per_ml) as sd_price_per_ml_c,
		mean(price_per_unit) as avg_price_per_unit_c, std(price_per_unit) as sd_price_per_unit_c
	from PUR_ALLINFO_20112014_b
	group by year, week;
quit;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_3a;by year week;
proc sort data=PCrisps_prices;by year week;
data panelist_week_shoptrip_brands_3b;
merge panelist_week_shoptrip_brands_3a(in=a) PCrisps_prices(in=b);by year week;if a;
rel_avg_price_per_ml_b_to_c=avg_price_per_ml_b/avg_price_per_ml_c;
rel_avg_price_per_unit_b_to_c=avg_price_per_unit_b/avg_price_per_unit_c;
run;




/*** 4) distribution***/
/***brand***/
	/***per 'retailer'***/
	/*prepare: create 'retailer'-column*/
	/*only for local_store_types that NE Gift or Work unit=>first check market shares*/
/*%macro rawdata (pur=, year=);
proc sort data=&pur;by shopcode;
proc sort data=dataCNp.shopcode;by shopcode;
data pur_s_&year;
merge &pur(in=a) dataCNp.shopcode(in=b);by shopcode;if a;
week=week(Date_of_purchase , 'w');
year=year(Date_of_purchase);
run;
%mend rawdata;
%rawdata(pur=dataCNp.purchase_2011, year=2011)
%rawdata(pur=dataCNp.purchase_2012, year=2012)
%rawdata(pur=dataCNp.purchase_2013, year=2013)
%rawdata(pur=dataCNp.purchase_2014, year=2014)

data pur_s_20112014;
set pur_s_2011 pur_s_2012 pur_s_2013 pur_s_2014;
where Local_store_type notin ('GIFT','WORK UNIT');
if year=2010 then delete;/*we don't want to take 2010 into account*/
/*if year=2011 and week=0 then delete;/*week 20110 only has 2 days*/
/*if year=2012 and week=0 then do year=2011;week=52;end;/*week 201152 has only 6 days and week 201200 only has 1 day*/
/*if year=2013 and week=0 then do year=2012;week=53;end;/*week 201253 has only 1 day and week 201300 only has 6 days*/
/*if year=2014 and week=0 then do year=2013;week=52;end;/*week 201352 has only 2 days and week 201400 only has 5 days*/
/*if year=2014 and week=51 then delete;/*week 201451 only has 5 days*/
/*run;

proc sql;
	create table storetypesales as
	select local_store_type, sum(Total_value_sales) as Total_value_sales_st
	from pur_s_20112014
	group by local_store_type;
quit;
proc sql;
	create table ttl_storetypesales as
	select local_store_type, sum(Total_value_sales_st) as Total_value_sales_ttl
	from storetypesales;
quit;
data IDATACN.storetypesales;
merge storetypesales ttl_storetypesales;by local_store_type;
ms_val_sls_st=Total_value_sales_st/Total_value_sales_ttl;
proc sort data=IDATACN.storetypesales;by descending ms_val_sls_st;run;
	
	/*Dceision: keep all store types=>calculate market shares of retailers*/
/*proc sql;
	create table val_ret as
	select Local_store_type, Banner_name, sum(Total_value_sales) as Total_value_sales_ret
	from pur_s_20112014
	group by Local_store_type, Banner_name;
quit;
proc sql;
	create table cumval_ret as
	select Local_store_type, Banner_name, sum(Total_value_sales_ret) as CumTotal_value_sales_ret
	from val_ret;
quit;
proc sort data=val_ret;by Local_store_type Banner_name;
proc sort data=cumval_ret nodup;by Local_store_type Banner_name;
data idatacn.msval_ret;
merge val_ret cumval_ret;by Local_store_type Banner_name;
ms_value_sales_ret=Total_value_sales_ret/CumTotal_value_sales_ret;
proc sort data=idatacn.msval_ret;by Local_store_type descending ms_value_sales_ret;run;
	/*only take those banner_names into account that have market share of >=1%,
	all other banner_names get artificial banner_name equal to the local_store_type*/
data banner_names_bve_ret;
set idatacn.msval_ret;
if ms_value_sales_ret>=.01 then banner_name_bve=banner_name;
	else banner_name_bve=Local_store_type;
keep Local_store_type Banner_name Banner_name_bve;run;
proc sort data=PUR_ALLINFO_20112014_b;by Local_store_type Banner_name;
proc sort data=banner_names_bve_ret;by Local_store_type Banner_name;
data PUR_ALLINFO_20112014_b1;
merge PUR_ALLINFO_20112014_b(in=a) banner_names_bve_ret;by Local_store_type Banner_name;if a;
if banner_name_bve='' then banner_name_bve=Local_store_type;run;

	/*prepare: overal market share per 'retailer'*/
/*proc sort data=pur_s_20112014;by Local_store_type Banner_name;
proc sort data=banner_names_bve_ret;by Local_store_type Banner_name;
data pur_s1_20112014;
merge pur_s_20112014(in=a) banner_names_bve_ret;by Local_store_type Banner_name;if a;
if banner_name_bve='' then banner_name_bve=Local_store_type;run;*/
/*proc sql;													
	create table allret_ as
	select * ,
		sum(Total_value_sales) as TotValue
	from pur_s1_20112014
	group by year, week;
quit;
proc sql;													
	create table allretB_ as
	select banner_name_bve , year , week , TotValue ,
		sum(Total_value_sales) as TotValueRet
	from allret_
	group by banner_name_bve, year , week, TotValue;
quit;
data retailer_unique_;
	set allretB_;
	keep banner_name_bve year week MS_ret;
	MS_ret=TotValueRet/TotValue;
run;
proc sort data=retailer_unique_ out=calendar_ nodupkey;
	by year week;
run;
data calendar_;
	set calendar_;
	keep year week ID;
	ID=1;
run;
proc sort data=retailer_unique_ out=retailer_ nodupkey;
	by banner_name_bve;
run;
data retailer_;
	set retailer_;
	keep banner_name_bve ID;
	ID=1;
run;
proc sql;
      create table cal_ret_ as
      select a.year, a.week, b.banner_name_bve
      from calendar_ as a, retailer_ as b
      where a.ID=b.ID;
quit;
proc sql;
      create table cal_ret_mkt_ as
      select a.* , b.MS_ret
      from cal_ret_ as a left join Retailer_unique_ as b
      on a.year=b.year AND a.week=b.week AND a.banner_name_bve=b.banner_name_bve ;
quit;
data cal_ret_mkt_;
	set cal_ret_mkt_;
	if MS_ret=. then MS_ret=0;
run;
proc sort data=cal_ret_mkt_;
	by banner_name_bve year week;
run;
proc copy in=work out=idatacn;select cal_ret_mkt_;run;
	/*calculate distribution*/
%macro dist (group=);
data ret__&group;
	set PUR_ALLINFO_20112014_b1;
	keep banner_name_bve year week I_&group;
	if BrandNumber="&group";
	I_&group=1;
run;
proc sort data=ret__&group nodupkey;
	by banner_name_bve year week;
run;
%mend dist;
%dist (group=Brand01) %dist (group=Brand02) %dist (group=Brand03) %dist (group=Brand04) %dist (group=Brand05)
%dist (group=Brand06) %dist (group=Brand07) %dist (group=Brand08);
data dist1_;
merge idatacn.Cal_ret_mkt_(in=A) ret__Brand01 ret__Brand02 ret__Brand03 ret__Brand04 ret__Brand05 
						ret__Brand06 ret__Brand07 ret__Brand08;
	by banner_name_bve year week;
	if A;
	array nums _numeric_;do over nums;if nums=. then nums=0;end;
	D1_Brand01=I_Brand01* LAG(MS_ret); 
	D1_Brand02=I_Brand02* LAG(MS_ret);
	D1_Brand03=I_Brand03* LAG(MS_ret);
	D1_Brand04=I_Brand04* LAG(MS_ret);
	D1_Brand05=I_Brand05* LAG(MS_ret);
	D1_Brand06=I_Brand06* LAG(MS_ret);
	D1_Brand07=I_Brand07* LAG(MS_ret);
	D1_Brand08=I_Brand08* LAG(MS_ret);
	if banner_name_bve NE lag(banner_name_bve) then D1_Brand01=.;
	if banner_name_bve NE lag(banner_name_bve) then D1_Brand02=.;
	if banner_name_bve NE lag(banner_name_bve) then D1_Brand03=.;
	if banner_name_bve NE lag(banner_name_bve) then D1_Brand04=.;
	if banner_name_bve NE lag(banner_name_bve) then D1_Brand05=.;
	if banner_name_bve NE lag(banner_name_bve) then D1_Brand06=.;
	if banner_name_bve NE lag(banner_name_bve) then D1_Brand07=.;
	if banner_name_bve NE lag(banner_name_bve) then D1_Brand08=.;
run;
proc sql;													
	create table dist2_ as
	select year , week,
		sum(D1_Brand01) as Brand01_distribution,
		sum(D1_Brand02) as Brand02_distribution,
		sum(D1_Brand03) as Brand03_distribution,
		sum(D1_Brand04) as Brand04_distribution,
		sum(D1_Brand05) as Brand05_distribution,
		sum(D1_Brand06) as Brand06_distribution,
		sum(D1_Brand07) as Brand07_distribution,
		sum(D1_Brand08) as Brand08_distribution
	from dist1_
	group by year, week;
quit;
proc sort data=dist2_;by year week;
proc transpose data=dist2_ out=dist_banner_name_bve;by year week;run;
data dist_banner_name_bve;
format BrandNumber $8.;
set dist_banner_name_bve;
BrandNumber=scan(_NAME_,1,'_');
Distr_retailer_b=COL1;
drop _NAME_ COL1;run;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_3c;by year week BrandNumber;
proc sort data=dist_banner_name_bve;by year week BrandNumber;
data panelist_week_shoptrip_brands_4;
merge panelist_week_shoptrip_brands_3c(in=a) dist_banner_name_bve(in=b);by year week BrandNumber;if a;
run;

/*create calendar as normally it's created in the Distribution step*/
proc sort data=PUR_ALLINFO_20112014_b1 out=calendar_ nodupkey;
	by year week;
run;
data calendar_;
	set calendar_;
	keep year week ID;
	ID=1;
run;
















/***  Last bought and/or received top brand***/
	/***brand***/
/*bought*/
data Last_Brand_Bought;
set panelist_week_shoptrip_brands_4;
keep Panelist year week shoptrip brand_in_shoptrip BrandNumber;
if PCrisps_bought=1;
if Brand_bought=1;run;
proc sort data=Last_Brand_Bought;by Panelist year week shoptrip brand_in_shoptrip BrandNumber;
data Last_Brand_Bought;
set Last_Brand_Bought;
by Panelist;
Lag_BrandNumber=lag(BrandNumber);
	if first.Panelist then do;
		Lag_BrandNumber=.;
		end;
drop BrandNumber;run;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_6;by Panelist year week shoptrip brand_in_shoptrip;
proc sort data=Last_Brand_Bought;by Panelist year week shoptrip brand_in_shoptrip;
data panelist_week_shoptrip_brands_5a;
merge panelist_week_shoptrip_brands_4(in=a) Last_Brand_Bought(in=b);by Panelist year week shoptrip brand_in_shoptrip;if a;
if Lag_BrandNumber=BrandNumber then Last_top8Brand_bought=1;else Last_top8Brand_bought=0;
drop lag_BrandNumber;run;
/*gift*/
data Last_Brand_Gift;
set panelist_week_shoptrip_brands_4;
keep Panelist year week shoptrip brand_in_shoptrip BrandNumber;
if PCrisps_gift=1;
if Brand_gift=1;run;
proc sort data=Last_Brand_Gift;by Panelist year week shoptrip brand_in_shoptrip BrandNumber;
data Last_Brand_Gift;
set Last_Brand_Gift;
by Panelist;
Lag_BrandNumber=lag(BrandNumber);
	if first.Panelist then do;
		Lag_BrandNumber=.;
		end;
drop BrandNumber;run;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_5a;by Panelist year week shoptrip brand_in_shoptrip;
proc sort data=Last_Brand_Gift;by Panelist year week shoptrip brand_in_shoptrip;
data panelist_week_shoptrip_brands_5b;
merge panelist_week_shoptrip_brands_5a(in=a) Last_Brand_Gift(in=b);by Panelist year week shoptrip brand_in_shoptrip;if a;
if Lag_BrandNumber=BrandNumber then Last_top8Brand_gift=1;else Last_top8Brand_gift=0;
drop lag_BrandNumber;run;
/*bought or gift*/
data Last_Brand_Bought_Gift;
set panelist_week_shoptrip_brands_4;
keep Panelist year week shoptrip brand_in_shoptrip BrandNumber;
if Brand_bought=1 OR Brand_gift=1;
run;
proc sort data=Last_Brand_Bought_Gift;by Panelist year week shoptrip brand_in_shoptrip BrandNumber;
data Last_Brand_Bought_Gift;
set Last_Brand_Bought_Gift;
by Panelist;
Lag_BrandNumber=lag(BrandNumber);
	if first.Panelist then do;
		Lag_BrandNumber=.;
		end;
drop BrandNumber;
run;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_5b;by Panelist year week shoptrip brand_in_shoptrip;
proc sort data=Last_Brand_Bought_Gift;by Panelist year week shoptrip brand_in_shoptrip;
data panelist_week_shoptrip_brands_5c;
merge panelist_week_shoptrip_brands_5b(in=a) Last_Brand_Bought_Gift(in=b);by Panelist year week shoptrip brand_in_shoptrip;if a;
if Lag_BrandNumber=BrandNumber then Last_top8Brand_bought_or_gift=1;else Last_top8Brand_bought_or_gift=0;
drop lag_BrandNumber;
if PCrisps_bought=1 AND Last_top8Brand_bought_or_gift=1 and Last_top8brand_bought=0 then Last_top8brand_gift=1;
if PCrisps_gift=1 AND Last_top8Brand_bought_or_gift=1 and Last_top8brand_gift=0 then Last_top8brand_bought=1;
run;
	







	/*** Initialization periods & brand dummies***/
/*first create 3 initialization period dummies: 
		1 that starts the moment we observe for the first time a panelist either bought or received a top 10 brand*/
data in_period_bg1;
set panelist_week_shoptrip_brands_5c;
keep Panelist yearweekbrandinshoptrip;
proc sort data=in_period_bg1 nodup;by Panelist yearweekbrandinshoptrip;
run;
proc sql;
	create table in_period_bg2 as
	select Panelist, yearweekbrandinshoptrip, min(yearweekbrandinshoptrip) as min_yearweekbrandinshoptrip_bg, max(yearweekbrandinshoptrip) as max_yearweekbrandinshoptrip_bg
	from in_period_bg1
	group by Panelist;
quit;
data in_period_bg3;
set in_period_bg2;
if yearweekbrandinshoptrip<(min_yearweekbrandinshoptrip_bg+1000000) then initialization_period_bg=1;else initialization_period_bg=0;
run;
data in_period_bg4;
set in_period_bg3;
if initialization_period_bg=0;run;
proc sql;
	create table in_period_bg5 as
	select Panelist, min(yearweekbrandinshoptrip) as min_yearweekbrandinshoptrip_bg_e, max(yearweekbrandinshoptrip) as max_yearweekbrandinshoptrip_bg_e
	from in_period_bg4
	group by Panelist;
quit;
proc sort data=in_period_bg3;by Panelist;
proc sort data=in_period_bg5;by Panelist;
data in_period_bg6;
merge in_period_bg3 in_period_bg5;by Panelist;
run;
	/*merge to temporary 'initialization periods'-table*/
proc sort data=in_period_bg1;by Panelist;
proc sort data=in_period_bg6;by Panelist;
data in_periods1;
merge in_period_bg1 in_period_bg6;by Panelist;
run;
		/*1 that starts the moment we observe for the first time a panelist bought a top 10 brand*/
data in_period_b1;
set panelist_week_shoptrip_brands_5c;
keep Panelist yearweekbrandinshoptrip;
if PCrisps_bought=1;
proc sort data=in_period_b1 nodup;by Panelist yearweekbrandinshoptrip;
run;
proc sql;
	create table in_period_b2 as
	select Panelist, yearweekbrandinshoptrip, min(yearweekbrandinshoptrip) as min_yearweekbrandinshoptrip_b, max(yearweekbrandinshoptrip) as max_yearweekbrandinshoptrip_b
	from in_period_b1
	group by Panelist;
quit;
data in_period_b3;
set in_period_b2;
if yearweekbrandinshoptrip<(min_yearweekbrandinshoptrip_b+1000000) then initialization_period_b=1;else initialization_period_b=0;
run;
data in_period_b4;
set in_period_b3;
if initialization_period_b=0;run;
proc sql;
	create table in_period_b5 as
	select Panelist, min(yearweekbrandinshoptrip) as min_yearweekbrandinshoptrip_b_e, max(yearweekbrandinshoptrip) as max_yearweekbrandinshoptrip_b_e
	from in_period_b4
	group by Panelist;
quit;
data in_period_b3a;
set in_period_b3;
drop yearweekbrandinshoptrip initialization_period_b;
proc sort data=in_period_b3a nodup;by Panelist;
proc sort data=in_period_b5;by Panelist;
data in_period_b6;
merge in_period_b3a in_period_b5;by Panelist;
run;
	/*merge to temporary 'initialization periods'-table*/
proc sort data=in_periods1;by Panelist;
proc sort data=in_period_b6;by Panelist;
data in_periods2;
merge in_periods1 in_period_b6;by Panelist;
if min_yearweekbrandinshoptrip_b NE '' AND yearweekbrandinshoptrip<(min_yearweekbrandinshoptrip_b+1000000) then initialization_period_b=1;
	else if min_yearweekbrandinshoptrip_b NE '' AND yearweekbrandinshoptrip>=(min_yearweekbrandinshoptrip_b+1000000) then initialization_period_b=0;
run;
		/*1 that starts the moment we observe for the first time a panelist received a top 10 brand*/
data in_period_g1;
set panelist_week_shoptrip_brands_5c;
keep Panelist yearweekbrandinshoptrip;
if PCrisps_gift=1;
proc sort data=in_period_g1 nodup;by Panelist yearweekbrandinshoptrip;
run;
proc sql;
	create table in_period_g2 as
	select Panelist, yearweekbrandinshoptrip, min(yearweekbrandinshoptrip) as min_yearweekbrandinshoptrip_g, max(yearweekbrandinshoptrip) as max_yearweekbrandinshoptrip_g
	from in_period_g1
	group by Panelist;
quit;
data in_period_g3;
set in_period_g2;
if yearweekbrandinshoptrip<(min_yearweekbrandinshoptrip_g+1000000) then initialization_period_g=1;else initialization_period_g=0;
run;
data in_period_g4;
set in_period_g3;
if initialization_period_g=0;run;
proc sql;
	create table in_period_g5 as
	select Panelist, min(yearweekbrandinshoptrip) as min_yearweekbrandinshoptrip_g_e, max(yearweekbrandinshoptrip) as max_yearweekbrandinshoptrip_g_e
	from in_period_g4
	group by Panelist;
quit;
data in_period_g3a;
set in_period_g3;
drop yearweekbrandinshoptrip initialization_period_g;
proc sort data=in_period_g3a nodup;by Panelist;
proc sort data=in_period_g5;by Panelist;
data in_period_g6;
merge in_period_g3a in_period_g5;by Panelist;
run;
	/*merge to temporary 'initialization periods'-table*/
proc sort data=in_periods2;by Panelist;
proc sort data=in_period_g6;by Panelist;
data in_periods3;
merge in_periods2 in_period_g6;by Panelist;
if min_yearweekbrandinshoptrip_g NE '' AND yearweekbrandinshoptrip<(min_yearweekbrandinshoptrip_g+1000000) then initialization_period_g=1;
	else if min_yearweekbrandinshoptrip_g NE '' AND yearweekbrandinshoptrip>=(min_yearweekbrandinshoptrip_g+1000000) then initialization_period_g=0;
run;
	/*merge to base dataset*/
proc sort data=in_periods3;by Panelist yearweekbrandinshoptrip;
proc sort data=panelist_week_shoptrip_brands_5c;by Panelist yearweekbrandinshoptrip;
data panelist_week_shoptrip_brands_6;
merge panelist_week_shoptrip_brands_5c(in=a) in_periods3;by Panelist yearweekbrandinshoptrip;if a;
if yearweekbrandinshoptrip=min_yearweekbrandinshoptrip_bg then do;
	Last_top8Brand_bought=.;
	Last_top8Brand_gift=.;
	Last_top8Brand_bought_or_gift=.;
	end;
if yearweekbrandinshoptrip<=min_yearweekbrandinshoptrip_b then Last_top8Brand_bought=.;
if yearweekbrandinshoptrip<=min_yearweekbrandinshoptrip_g then Last_top8Brand_gift=.;
if Brand_latinname='' then A=1;else A=0;/*NOT ALLOWED TO SHARE BRAND NAMES!!!*/
if Brand_latinname='' then B=1;else B=0;
if Brand_latinname='' then C=1;else C=0;
if Brand_latinname='' then D=1;else D=0;
if Brand_latinname='' then E=1;else E=0;
if Brand_latinname='' then F=1;else F=0;
if Brand_latinname='' then G=1;else G=0;
if Brand_latinname='' then H=1;else H=0;
run;


















data pan_wk_sh_br_6_PCrisps;
set panelist_week_shoptrip_brands_6;
proc copy in=work out=idataCN;select pan_wk_sh_br_6_PCrisps;run;






















/****************Make selections from dataset idataCN.pan_wk_sh_br_9_PCrisps ****************?


/*** percentage spent on brand 1 - 10 ***/
proc sql;
	create table spent_on_PCrisps as
	select Panelist, sum(Total_value_sales) as ttl_val_sls_c
	from Pur_allinfo_20112014_b
	group by Panelist;
quit;
proc sql;
	create table spent_on_top8 as
	select Panelist, sum(val_sls_b) as ttl_val_sls_top8
	from panelist_week_shoptrip_brands_6
	group by Panelist;
quit;
proc sort data=spent_on_PCrisps;by Panelist;
proc sort data=spent_on_top8;by Panelist;
data pc_spent_on_top8;
merge spent_on_PCrisps spent_on_top8;by Panelist;
if ttl_val_sls_c=.  then ttl_val_sls_c=0;
if ttl_val_sls_c NE 0 then do;
	rel_ttl_val_sls_top8_to_c=ttl_val_sls_top8/ttl_val_sls_c;
	if rel_ttl_val_sls_top8_to_c>=.7 then rel_ttl_val_sls_top8_to_c_70=1;else rel_ttl_val_sls_top8_to_c_70=0;
	end;
run;



/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_6;by Panelist;
proc sort data=pc_spent_on_top8;by Panelist;
data panelist_week_shoptrip_brands_7;
merge panelist_week_shoptrip_brands_6(in=a) pc_spent_on_top8;by Panelist;if a;run;




/***  number of different brands from top8***/
	/*in purchase history*/
/*bought or received*/
data pre_nr_diff_brands_bg;
set panelist_week_shoptrip_brands_7;
if Brand_bought=1 OR Brand_gift=1;
keep Panelist BrandNumber;
proc sort data=pre_nr_diff_brands_bg nodup;by Panelist BrandNumber;
proc sql;
	create table nr_diff_brands_bg as
	select Panelist, count(BrandNumber) as nr_diff_top8brands_bg
	from pre_nr_diff_brands_bg
	group by Panelist;
quit;
/*bought*/
data pre_nr_diff_brands_b;
set panelist_week_shoptrip_brands_7;
if Brand_bought=1;
keep Panelist BrandNumber Brand_bought;
proc sort data=pre_nr_diff_brands_b nodup;by Panelist BrandNumber Brand_bought;
proc sql;
	create table nr_diff_brands_b as
	select Panelist, sum(Brand_bought) as nr_diff_top8brands_b
	from pre_nr_diff_brands_b
	group by Panelist;
quit;
/*gift*/
data pre_nr_diff_brands_g;
set panelist_week_shoptrip_brands_7;
if Brand_gift=1;
keep Panelist BrandNumber Brand_gift;
proc sort data=pre_nr_diff_brands_g nodup;by Panelist BrandNumber Brand_gift;
proc sql;
	create table nr_diff_brands_g as
	select Panelist, sum(Brand_gift) as nr_diff_top8brands_g
	from pre_nr_diff_brands_g
	group by Panelist;
quit;
proc sort data=nr_diff_brands_bg;by Panelist;
proc sort data=nr_diff_brands_b;by Panelist;
proc sort data=nr_diff_brands_g;by Panelist;
data nr_diff_brands;
merge nr_diff_brands_bg nr_diff_brands_b nr_diff_brands_g;by Panelist;
if nr_diff_top8brands_bg=. then nr_diff_top8brands_bg=0;
if nr_diff_top8brands_b=. then nr_diff_top8brands_b=0;
if nr_diff_top8brands_g=. then nr_diff_top8brands_g=0;
run;
	/*in estimation period*/
	/*bought or received*/
data pre_nr_diff_brands_bg_e;
set panelist_week_shoptrip_brands_7;
if 	initialization_period_b=0;
if Brand_bought=1 OR Brand_gift=1;
keep Panelist BrandNumber;
proc sort data=pre_nr_diff_brands_bg_e nodup;by Panelist BrandNumber;
proc sql;
	create table nr_diff_brands_bg_e as
	select Panelist, count(BrandNumber) as nr_diff_top8brands_bg_e
	from pre_nr_diff_brands_bg_e
	group by Panelist;
quit;
/*bought*/
data pre_nr_diff_brands_b_e;
set panelist_week_shoptrip_brands_10;
if 	initialization_period_b=0;
if Brand_bought=1;
keep Panelist BrandNumber Brand_bought;
proc sort data=pre_nr_diff_brands_b_e nodup;by Panelist BrandNumber Brand_bought;
proc sql;
	create table nr_diff_brands_b_e as
	select Panelist, sum(Brand_bought) as nr_diff_top8brands_b_e
	from pre_nr_diff_brands_b_e
	group by Panelist;
quit;
/*gift*/
data pre_nr_diff_brands_g_e;
set panelist_week_shoptrip_brands_10;
if 	initialization_period_b=0;
if Brand_gift=1;
keep Panelist BrandNumber Brand_gift;
proc sort data=pre_nr_diff_brands_g_e nodup;by Panelist BrandNumber Brand_gift;
proc sql;
	create table nr_diff_brands_g_e as
	select Panelist, sum(Brand_gift) as nr_diff_top8brands_g_e
	from pre_nr_diff_brands_g_e
	group by Panelist;
quit;
proc sort data=nr_diff_brands_bg_e;by Panelist;
proc sort data=nr_diff_brands_b_e;by Panelist;
proc sort data=nr_diff_brands_g_e;by Panelist;
data nr_diff_brands_e;
merge nr_diff_brands_bg_e nr_diff_brands_b_e nr_diff_brands_g_e;by Panelist;
if nr_diff_top8brands_bg_e=. then nr_diff_top8brands_bg_e=0;
if nr_diff_top8brands_b_e=. then nr_diff_top8brands_b_e=0;
if nr_diff_top8brands_g_e=. then nr_diff_top8brands_g_e=0;
run;
	/*in initiliazation period*/
	/*bought or received*/
data pre_nr_diff_brands_bg_i;
set panelist_week_shoptrip_brands_10;
if 	initialization_period_b=1;
if Brand_bought=1 OR Brand_gift=1;
keep Panelist BrandNumber;
proc sort data=pre_nr_diff_brands_bg_i nodup;by Panelist BrandNumber;
proc sql;
	create table nr_diff_brands_bg_i as
	select Panelist, count(BrandNumber) as nr_diff_top8brands_bg_i
	from pre_nr_diff_brands_bg_i
	group by Panelist;
quit;
/*bought*/
data pre_nr_diff_brands_b_i;
set panelist_week_shoptrip_brands_10;
if 	initialization_period_b=1;
if Brand_bought=1;
keep Panelist BrandNumber Brand_bought;
proc sort data=pre_nr_diff_brands_b_i nodup;by Panelist BrandNumber Brand_bought;
proc sql;
	create table nr_diff_brands_b_i as
	select Panelist, sum(Brand_bought) as nr_diff_top8brands_b_i
	from pre_nr_diff_brands_b_i
	group by Panelist;
quit;
/*gift*/
data pre_nr_diff_brands_g_i;
set panelist_week_shoptrip_brands_7;
if 	initialization_period_b=1;
if Brand_gift=1;
keep Panelist BrandNumber Brand_gift;
proc sort data=pre_nr_diff_brands_g_i nodup;by Panelist BrandNumber Brand_gift;
proc sql;
	create table nr_diff_brands_g_i as
	select Panelist, sum(Brand_gift) as nr_diff_top8brands_g_i
	from pre_nr_diff_brands_g_i
	group by Panelist;
quit;
proc sort data=nr_diff_brands_bg_i;by Panelist;
proc sort data=nr_diff_brands_b_i;by Panelist;
proc sort data=nr_diff_brands_g_i;by Panelist;
data nr_diff_brands_i;
merge nr_diff_brands_bg_i nr_diff_brands_b_i nr_diff_brands_g_i;by Panelist;
if nr_diff_top8brands_bg_i=. then nr_diff_top8brands_bg_i=0;
if nr_diff_top8brands_b_i=. then nr_diff_top8brands_b_i=0;
if nr_diff_top8brands_g_i=. then nr_diff_top8brands_g_i=0;
run;
	/*merge to base dataset*/
proc sort data=panelist_week_shoptrip_brands_7;by Panelist;
proc sort data=nr_diff_brands;by Panelist;
proc sort data=nr_diff_brands_e;by Panelist;
proc sort data=nr_diff_brands_i;by Panelist;
data panelist_week_shoptrip_brands_8;
merge panelist_week_shoptrip_brands_7(in=a) nr_diff_brands nr_diff_brands_e nr_diff_brands_i;by Panelist;if a;
run;















/***  number of shopping trips (purchase/gift or actual purchase) in initialization&estimation period ***/

/*number of shopping trips of people who spent >=70% on top 10*/
data pan_wk_sh_br_9_70;
set panelist_week_shoptrip_brands_8;
if rel_ttl_val_sls_top8_to_c_70=1;run;

proc sort data=pan_wk_sh_br_9_70 nodupkey out=pan_wk_sh_br_12_70_nod;by Panelist;
proc freq data=pan_wk_sh_br_9_70_nod;tables ttl_nr_shoptrips_bg_i ttl_nr_shoptrips_b_e;run;














/*select panelists based on selection criteria:
	have spent 70% or more of their category budget on the top 10, AND 
	have 2 times or more bought or received a gift in the initialization period AND 
	2 times or more bought in estimation period*/
/*select only relevant columns, replace missing values*/
data pre_PAN_WK_SH_BR_26112015_sel;
set panelist_week_shoptrip_brands_9;
if rel_ttl_val_sls_top8_to_c_70=1 AND ttl_nr_shoptrips_bg_i>=2 AND ttl_nr_shoptrips_b_e>=2;
if Distr_retailer_b='.' then Distr_retailer_b=0;
if pc_SKUs_promo_b='.' then pc_SKUs_promo_b=0;
if avg_price_per_ml_b='.' then avg_price_per_ml_b=0;
run;

/*VERY IMPORTANT! SORT BY BRAND DUMMIES SO THAT THERE'S A DIAGONAL OF ONES (MAKE SURE REFERENCE BRAND IS IN LAST COLUMN)!!!*/
proc sort data=pre_PAN_WK_SH_BR_26112015_sel;by Panelist yearweekbrandinshoptrip 
descending H descending G descending F descending E descending D descending C descending B descending A;run;
    
/*finally create holdout_sample column (75% vs 25%)*/
/*total nr of selected panelists*/
data all_selected_panelists;
set pre_PAN_WK_SH_BR_26112015_sel;
keep Panelist;run;
proc sort data=all_selected_panelists nodup;by Panelist;run;
/*NOTE: The data set WORK.ALL_SELECTED_PANELISTS has 18349 observations and 1 variables*/

/*draw random sample: 25% of 18349 panelists=4587*/
PROC SURVEYSELECT DATA=all_selected_panelists OUT=holdout_panelists METHOD=SRS
SAMPSIZE=4587 SEED=1234567;
RUN;

proc sort data=pre_PAN_WK_SH_BR_26112015_sel;by Panelist;
proc sort data=holdout_panelists;by Panelist;
data PAN_WK_SH_BR_26112015_sel;
retain Panelist Vol_sls_b Vol_gift_b initialization_period_b Brand_bought Brand_gift 
avg_price_per_ml_b Distr_retailer_b assort_width_b  
H G F E D C B A holdout_sample;
merge pre_PAN_WK_SH_BR_26112015_sel holdout_panelists(in=a);by Panelist;
if a then holdout_sample=1;else holdout_sample=0;
keep Panelist Vol_sls_b Vol_gift_b initialization_period_b Brand_bought Brand_gift 
avg_price_per_ml_b Distr_retailer_b assort_width_b 
H G F E D C B A holdout_sample;run;

proc copy in=work out=idatacn;select PAN_WK_SH_BR_26112015_sel;run;


/*copy 'complete' dataset to permanent library: include column holdout_sample
0=not holdout
1=holdout
.=does not meet selection critria*/
data all_holdout_panelists;
set PAN_WK_SH_BR_26112015_sel;
keep Panelist Holdout_sample;
proc sort data=all_holdout_panelists nodup;by Panelist Holdout_sample;
proc sort data=panelist_week_shoptrip_brands_9;by Panelist;
data panelist_week_shoptrip_brands_9;
merge panelist_week_shoptrip_brands_9 all_holdout_panelists;by Panelist;
data pan_wk_sh_br_9_PCrisps;
set panelist_week_shoptrip_brands_9;
proc copy in=work out=idatacn;select pan_wk_sh_br_12_PCrisps;run;






/*PREPARATION TO RUN IN GAUSS*/

/*double check if #rows in dataset is equal to #shoptrips (bought or gift) * 8*/
data check;
set PAN_WK_SH_BR_26112015_sel;
if brand_bought or brand_gift=1;
run;
/*NOTE: There were 383950 observations read from the data set WORK.PAN_WK_SH_BR_26112015_SEL.
NOTE: The data set WORK.CHECK has 54850 observations and 24 variables.
=>378780*8=3030240=> ok!*/

/*check number of bought shoptrips vs gift shoptrips*/
data check_bought;
set PAN_WK_SH_BR_26112015_sel;
if brand_bought=1;
run;
/*NOTE: The data set WORK.CHECK_BOUGHT has 348912 observations and 25 variables.*/
data check_gift;
set PAN_WK_SH_BR_26112015_sel;
if brand_gift=1;
run;
/*NOTE: The data set WORK.CHECK_GIFT has 29868 observations and 25 variables.*/

/*check number of households*/
proc sort data=PAN_WK_SH_BR_26112015_sel nodupkey out=check_nr_pan;by panelist;run;
/*NOTE: The data set WORK.CHECK_NR_PAN has 18349 observations and 25 variables.*/



/*make selection if holdout=1*/
/*double check if #rows in dataset is equal to #shoptrips (bought or gift) * 8*/
data PAN_WK_SH_BR_26112015_sel_ho;
set PAN_WK_SH_BR_26112015_sel;
if holdout_sample=1;run;
/*NOTE: There were 3030240 observations read from the data set WORK.PAN_WK_SH_BR_26112015_SEL.
NOTE: The data set WORK.PAN_WK_SH_BR_26112015_SEL_HO has 747496 observations and 25
      variables.*/

proc copy in=work out=idatacn;select PAN_WK_SH_BR_26112015_sel_ho;run;
/*export to text for Els*/
PROC EXPORT DATA= IDATACN.PAN_WK_SH_BR_26112015_sel_ho
            OUTFILE= "E:\AiMark projects\Brand Growth 2.0\Subprojects\Global Branding Strategy\Data\Internal data\CN\PAN_WK_SH_BR_26112015_sel_ho.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;

data check;
set PAN_WK_SH_BR_26112015_sel_ho;
if brand_bought or brand_gift=1;
run;
/*NOTE: There were 747496 observations read from the data set
      WORK.PAN_WK_SH_BR_26112015_SEL_HO.
NOTE: The data set WORK.CHECK has 93437 observations and 25 variables.
=>93437*8=747496 => ok!*/

/*check number of bought shoptrips vs gift shoptrips*/
data check_bought;
set PAN_WK_SH_BR_26112015_sel_ho;
if brand_bought=1;
run;
/*NOTE: The data set WORK.CHECK_BOUGHT has 86338 observations and 25 variables.*/
data check_gift;
set PAN_WK_SH_BR_26112015_sel_ho;
if brand_gift=1;
run;
/*NOTE: The data set WORK.CHECK_GIFT has 7099 observations and 25 variables.*/

/*check number of households*/
proc sort data=PAN_WK_SH_BR_26112015_sel_ho nodupkey out=check_nr_pan;by panelist;run;
/*NOTE: The data set WORK.CHECK_NR_PAN has 4587 observations and 25 variables.*/



/*CREATE TIMES DATASET: PER PANELIST TOTAL NR OF TRIPS (GIFTS & PURCHASES IN INITIALIZATION & ESTIMATION PERIOD)*/
data pre2_times;
set idatacn.pan_wk_sh_br_9_PCrisps;
if Holdout_sample=1;
if brand_bought or brand_gift=1;
keep Panelist yearweekbrandinshoptrip;
proc sort data=pre2_times nodup;by Panelist yearweekbrandinshoptrip;
proc sql;
	create table pre_times as
	select Panelist, count(yearweekbrandinshoptrip) as nr_trips_bought_or_gift
	from pre2_times
	group by Panelist;
quit;
data PCrisps_times;
set pre_times;
keep nr_trips_bought_or_gift;run;
/*export to text*/
PROC EXPORT DATA= PCrisps_times
            OUTFILE= "\PCrisps_times.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;


/*CREATE PURCHASES DATASET: PER PANELIST TOTAL NR OF TRIPS (PURCHASES ONLY IN INITIALIZATION & ESTIMATION PERIOD)*/
data pre2_purchases;
set idatacn.pan_wk_sh_br_9_PCrisps;
if Holdout_sample=1;
if brand_bought=1;
keep Panelist yearweekbrandinshoptrip;
proc sort data=pre2_purchases nodup;by Panelist yearweekbrandinshoptrip;
proc sql;
	create table pre_purchases as
	select Panelist, count(yearweekbrandinshoptrip) as nr_trips_bought
	from pre2_purchases
	group by Panelist;
quit;
data PCrisps_purchases;
set pre_purchases;
keep nr_trips_bought;run;
/*export to text*/
PROC EXPORT DATA= PCrisps_purchases
            OUTFILE= "\PCrisps_purchases.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;























/*SELECTED PANELISTS: select only those people who spent 70% or more of their category budget on the top 8
AND have more than 2 'shopping' trips in init&est period*/
data pan_wk_sh_br_12_70_nod_sel;
set pan_wk_sh_br_12_70_nod;
if ttl_nr_shoptrips_bg_i=>2 AND ttl_nr_shoptrips_b_e=>2;run;
data selected_panelists;
set pan_wk_sh_br_12_70_nod_sel;
keep Panelist;
proc sort data=selected_panelists nodup;by Panelist;run;
proc sort data=PUR_ALLINFO_20112014;by Panelist;
data sel_panelists;
merge PUR_ALLINFO_20112014 selected_panelists(in=a);by Panelist;if a;
proc sort data=sel_panelists nodup;by Panelist Quarter;run;


/*nr panelists in selected dataset*/
proc sort data=sel_panelists nodupkey out=sel_pan;by Panelist;run;
/*NOTE: The data set WORK.SEL_PAN has 18349 observations and 8 variables.*/
































/*ADD ADVERTISING SPENTS TO IT*/
/*first draw a graph of advertising spent per brand per month*/
libname edatacn '\Kantar media';

/*first change brand names the same way as I did for the KWP household panel data (see very first datastep of this program above)*/
data addata_Cat54;
set edatacn.addata_Cat54;
/*remove immediately brands that do not belong to top 10 KWP*/
where Brand NE '' and Brand_latinname NE '';
run;



/*then blow up table so that every brand has every month*/
data yearmonth20112014;
set addata_Cat54;
var=1;
keep year month var;
proc sort data=yearmonth20112014 nodup;by year month;run;
/*NOTE: The data set WORK.YEARMONTH20112014 has 48 observations and 3 variables.
=> ok; 4 years * 12 months = 48*/
/*create list of brands*/
data brands; 
set addata_Cat54;
var=1;
keep Brand Brand_latinname var;
proc sort data=brands nodup;by Brand Brand_latinname;run;
/*NOTE: The data set WORK.BRANDS has 8 observations and 3 variables.
=> that's ok, we only have advertising data for 8 brands*/



proc sql;
	create table brands_yearmonth20112014 as
	select *
	from brands as a, yearmonth20112014 as b
	where a.var=b.var;
quit;
/*NOTE: Table WORK.BRANDS_YEARMONTH20112014 created, with 576 rows and 5 columns.
=> ok 48 months * 8 brands = 384*/

/*now use this as a base file to merge addata to it, but first create colums with adspends per media type and 
sum adspends from different media types to get total adspends per brand per month*/
%macro medtype (mediatype=, media_type=, medtype=);
data addata_Cat54_&media_type;
set addata_Cat54;
where Media_type=&mediatype;
proc sql;
	create table Addata_b_Cat54_per&media_type as
	select year, month, Brand, Brand_latinname, sum(Gross_AdSpend_b) as &medtype._Gross_AdSpend_b
	from addata_Cat54_&media_type
	group by year, month, Brand, Brand_latinname;
quit;
%mend medtype;
%medtype (mediatype='Newspaper', media_type=Newspaper, medtype=newsp)
%medtype (mediatype='Radio', media_type=Radio, medtype=rad)
%medtype (mediatype='Outdoor', media_type=Outdoor, medtype=outd)
%medtype (mediatype='TV', media_type=TV, medtype=TV)
%medtype (mediatype='Metro Station', media_type=Metro_Station, medtype=metr)
%medtype (mediatype='Magazine', media_type=Magazine, medtype=mag)
%medtype (mediatype='Website', media_type=Website, medtype=webs);
proc sql;
	create table Addata_b_Cat54_allmed as
	select year, month, Brand, Brand_latinname, sum(Gross_AdSpend_b) as allmed_Gross_AdSpend_b
	from addata_Cat54
	group by year, month, Brand, Brand_latinname;
quit;

/*merge all to base file and check whether summing different mediatypes gives same as allmed_Ad_Spend_Gross_b*/
proc sort data=brands_yearmonth20112014;by year month Brand Brand_latinname;
data Addata_Cat54_allmonths;
merge brands_yearmonth20112014(in=a) Addata_b_Cat54_allmed Addata_b_Cat54_perNewspaper Addata_b_Cat54_perRadio Addata_b_Cat54_perOutdoor Addata_b_Cat54_perTV Addata_b_Cat54_perMetro_Station Addata_b_Cat54_perMagazine Addata_b_Cat54_perWebsite;
by year month Brand Brand_latinname;if a;
/*in months with zero spending, adspend=0*/
if allmed_Gross_AdSpend_b=. then allmed_Gross_AdSpend_b=0;
if newsp_Gross_AdSpend_b=. then newsp_Gross_AdSpend_b=0;
if rad_Gross_AdSpend_b=. then rad_Gross_AdSpend_b=0;
if outd_Gross_AdSpend_b=. then outd_Gross_AdSpend_b=0;
if TV_Gross_AdSpend_b=. then TV_Gross_AdSpend_b=0;
if metr_Gross_AdSpend_b=. then metr_Gross_AdSpend_b=0;
if mag_Gross_AdSpend_b=. then mag_Gross_AdSpend_b=0;
if webs_Gross_AdSpend_b=. then webs_Gross_AdSpend_b=0;
drop var;
run;

/*create weekly brand adspends iso monthly adspends*/
/*first blow up monthly table to weekly table: create table with Date, week, month, quarter and year (for creation of Pur_allinfo_20112014 se every beginning of program)*/
data dwmqy20112014;
set Pur_allinfo_20112014;
keep Date_of_purchase week month Quarter year var;
proc sort data=dwmqy20112014 nodup;by Date_of_purchase week month Quarter year;run;

proc sql;
	create table brands_dwmqy20112014 as
	select *
	from brands as a, dwmqy20112014 as b
	where a.var=b.var;
quit;

proc sort data=Addata_Cat54_allmonths;by year month Brand Brand_latinname;
proc sort data=brands_dwmqy20112014;by year month Brand Brand_latinname;
data Addata_Cat54_alldwmqy;
merge brands_dwmqy20112014(in=a) Addata_Cat54_allmonths;by year month Brand Brand_latinname;if a;run;

/*now smooth monthly spendings across weeks: to do this, first calculate spendings per day so that sum of daily spendings in a particular month equals monthly spending as delivered by Kantar*/
proc sql;
	create table nr_days_in_month as
	select year, month, count(Date_of_purchase) as nr_days_in_month
	from dwmqy20112014
	group by year, month;
quit;
proc sort data=Addata_Cat54_alldwmqy;by year month;
proc sort data=nr_days_in_month;by year month;
data Addata_Cat54_wksmooth1;
merge Addata_Cat54_alldwmqy(in=a) nr_days_in_month;by year month;if a;
dy_allmed_Gross_AdSpend_b=allmed_Gross_AdSpend_b/nr_days_in_month;run;
proc sql;
	create table Addata_b_Cat54_wksmooth2 as
	select year, week, Brand, Brand_latinname, sum(dy_allmed_Gross_AdSpend_b) as wk_allmed_Gross_AdSpend_b
	from Addata_Cat54_wksmooth1
	group by year, week, Brand, Brand_latinname;
quit;








/*monthly adspends per category*/
data pre_Cat54_cat_medtype month;
set addata_Cat54;
keep year month media_type Gross_AdSpend_c;
proc sort data=pre_Cat54_cat_medtype nodup;by year month media_type Gross_AdSpend_c;run;
%macro medtype (mediatype=, media_type=, medtype=);
data addata_Cat54_cat_&media_type;
set pre_Cat54_cat_medtype;
where Media_type=&mediatype;
proc sql;
	create table Addata_c_Cat54_per&media_type as
	select year, month, sum(Gross_AdSpend_c) as &medtype._Gross_AdSpend_c
	from addata_Cat54_cat_&media_type
	group by year, month;
quit;
%mend medtype;
%medtype (mediatype='Newspaper', media_type=Newspaper, medtype=newsp)
%medtype (mediatype='Radio', media_type=Radio, medtype=rad)
%medtype (mediatype='Outdoor', media_type=Outdoor, medtype=outd)
%medtype (mediatype='TV', media_type=TV, medtype=TV)
%medtype (mediatype='Metro Station', media_type=Metro_Station, medtype=metr)
%medtype (mediatype='Magazine', media_type=Magazine, medtype=mag)
%medtype (mediatype='Website', media_type=Website, medtype=webs);
proc sql;
	create table Addata_c_Cat54_allmed as
	select year, month, sum(Gross_AdSpend_c) as allmed_Gross_AdSpend_c
	from pre_Cat54_cat_medtype
	group by year, month;
quit;

/*merge all to base file and check whether summing different mediatypes gives same as allmed_Ad_Spend_Gross_b*/
proc sort data=yearmonth20112014;by year month;
data Addata_c_Cat54_allmonths;
merge yearmonth20112014(in=a) Addata_c_Cat54_allmed Addata_c_Cat54_perNewspaper Addata_c_Cat54_perRadio Addata_c_Cat54_perOutdoor Addata_c_Cat54_perTV Addata_c_Cat54_perMetro_Station Addata_c_Cat54_perMagazine Addata_c_Cat54_perWebsite;
by year month;if a;
/*in months with zero spending, adspend=0*/
if allmed_Gross_AdSpend_c=. then allmed_Gross_AdSpend_c=0;
if newsp_Gross_AdSpend_c=. then newsp_Gross_AdSpend_c=0;
if rad_Gross_AdSpend_c=. then rad_Gross_AdSpend_c=0;
if outd_Gross_AdSpend_c=. then outd_Gross_AdSpend_c=0;
if TV_Gross_AdSpend_c=. then TV_Gross_AdSpend_c=0;
if metr_Gross_AdSpend_c=. then metr_Gross_AdSpend_c=0;
if mag_Gross_AdSpend_c=. then mag_Gross_AdSpend_c=0;
if webs_Gross_AdSpend_c=. then webs_Gross_AdSpend_c=0;
drop var;
run;

/*merge monthly spendings per brand and per category*/
proc sort data=Addata_Cat54_allmonths;by year month;
proc sort data=Addata_c_Cat54_allmonths;by year month;
data Addata_b_and_c_Cat54_allmonths;
merge Addata_Cat54_allmonths Addata_c_Cat54_allmonths;by year month;run;










/*create weekly cat adspends iso monthly adspends*/
/*first blow up monthly table to weekly table: create table with Date, week, month, quarter and year (for creation of Pur_allinfo_20112014 se every beginning of program)*/
proc sort data=Addata_c_Cat54_allmonths;by year month;
proc sort data=dwmqy20112014;by year month;
data Addata_c_Cat54_wksmooth1;
merge dwmqy20112014(in=a) Addata_c_Cat54_allmonths nr_days_in_month;by year month;if a;
dy_allmed_Gross_AdSpend_c=allmed_Gross_AdSpend_c/nr_days_in_month;run;
proc sql;
	create table Addata_c_Cat54_wksmooth2 as
	select year, week, sum(dy_allmed_Gross_AdSpend_c) as wk_allmed_Gross_AdSpend_c
	from Addata_c_Cat54_wksmooth1
	group by year, week;
quit;

/*merge weekly brand and cat ad spendings*/
data weekly_adspend_Cat54;
merge Addata_c_Cat54_wksmooth2 Addata_b_Cat54_wksmooth2;by year week;run;



















/*now read in CPI to weigh weekly prices and weekly adspends*/
/*yearly*/
PROC IMPORT OUT= WORK.CPI 
            DATAFILE= "\Data_Extract_From_World_Development_Indicators.xlsx" 
            DBMS=EXCELCS REPLACE;
     RANGE="Data$"; 
     SCANTEXT=YES;
     USEDATE=YES;
     SCANTIME=YES;
RUN;
data CPI;
set CPI;
where Series_name NE '';
keep Series_Name _011__YR2011_--_014__YR2014_;run;
proc transpose data=CPI out=CPI_t;run;
data CPI_t;
set CPI_t;
rename COL1=yearly_CPI;label COL1=yearly_CPI;
if _LABEL_='2011 (YR2011)' then year=2011;
if _LABEL_='2012 (YR2012)' then year=2012;
if _LABEL_='2013 (YR2013)' then year=2013;
if _LABEL_='2014 (YR2014)' then year=2014;
keep year COL1;
run;









/*first: weigh adspends data*/
data weekly_adspend_Cat54_CPI;
merge weekly_adspend_Cat54 CPI_t;by year;
CPI_wk_allmed_Gross_AdSpend_b=100*wk_allmed_Gross_AdSpend_b/yearly_CPI;
CPI_wk_allmed_Gross_AdSpend_c=100*wk_allmed_Gross_AdSpend_c/yearly_CPI;
run;

/*now create 'adstock' variable: for week t, adstock equals (1-lambda)*advertising in week t + lambda*AdStock in week t-1*/
/*adstock for brands*/
proc sort data=weekly_adspend_Cat54_CPI out=weekly_adspend_Cat54_CPI_b;by Brand Brand_latinname year week;run;
/*let lambda deviate between .5-.9*/
%macro adst (lambda=,lambda_=);
data weekly_adspend_Cat54_CPI_b;
  set weekly_adspend_Cat54_CPI_b;
  by Brand;
  retain AdStock&lambda._b;
  if first.Brand then do;
    count=0;
    AdStock&lambda._b=CPI_wk_allmed_Gross_AdSpend_b*.5;/*initial amount counts as half (preference of Broadbent 1984)*/
  end;
  count+1;
  if count ge 0 then AdStock&lambda._b = sum(CPI_wk_allmed_Gross_AdSpend_b*(1-&lambda_), AdStock&lambda._b*&lambda_);/*weekly advertising retention rate os .8 (George, Mercer and Wilson 1996)*/
  else AdStock&lambda._b=.;
run;
data weekly_adspend_Cat54_CPI_b;
  set weekly_adspend_Cat54_CPI_b;
drop count;run;
%mend adst;
%adst (lambda=80, lambda_=.8);




/*adstock for category*/
proc sort data=weekly_adspend_Cat54_CPI out=weekly_adspend_Cat54_CPI_c nodupkey;by year week;run;
data weekly_adspend_Cat54_CPI_c;
set weekly_adspend_Cat54_CPI_c;
keep year week CPI_wk_allmed_Gross_AdSpend_c;run;
/*let lambda deviate between .5-.9*/
%macro adst (lambda=,lambda_=);
data weekly_adspend_Cat54_CPI_c;
set weekly_adspend_Cat54_CPI_c;
    if _N_ = 1 then do;
    AdStock&lambda._c=CPI_wk_allmed_Gross_AdSpend_c*.5;/*initial amount counts as half (preference of Broadbent 1984)*/
    retain AdStock&lambda._c;
end;
else do;
  AdStock&lambda._c = sum(CPI_wk_allmed_Gross_AdSpend_c*(1-&lambda_), AdStock&lambda._c*&lambda_);/*weekly advertising retention rate os .8 (George, Mercer and Wilson 1996)*/
end;
run;
%mend adst;
%adst (lambda=80, lambda_=.8);

/*now merge brand adstocks and category adstocks*/
proc sort data=weekly_adspend_Cat54_CPI_b;by year week;
proc sort data=weekly_adspend_Cat54_CPI_c;by year week;
data weekly_adspend_Cat54_CPI_bc;
merge weekly_adspend_Cat54_CPI_b weekly_adspend_Cat54_CPI_c;by year week;
SOV_AdStock80_b_to_c=AdStock80_b/AdStock80_c;
run;

/*second: weigh prices*/
data pre_w_prices_top8;
set idatacn.pan_wk_sh_br_9_PCrisps;
keep year week Brand Brand_latinname avg_price_per_ml_b;
proc sort data=pre_w_prices_top8 nodup;by year week Brand Brand_latinname avg_price_per_ml_b;run; 
data weekly_prices_CPI;
merge pre_w_prices_top8 CPI_t;by year;
CPI_avg_price_per_ml_b=100*avg_price_per_ml_b/yearly_CPI;
keep year week Brand Brand_latinname CPI_avg_price_per_ml_b;
run;









/*now add all columns to the dataset*/
/*start from complete dataset*/
data pan_wk_sh_br_9_PCrisps;
set idatacn.pan_wk_sh_br_9_PCrisps;
month=month(Date_of_purchase);
run;
proc sort data=pan_wk_sh_br_9_PCrisps;by year month Brand Brand_latinname;
proc sort data=Addata_b_and_c_Cat54_allmonths;by year month Brand Brand_latinname;
data pan_wk_sh_br_9_PCrisps_ad;
merge pan_wk_sh_br_9_PCrisps(in=a) Addata_b_and_c_Cat54_allmonths;by year month Brand Brand_latinname;if a;run;
run;
proc sort data=pan_wk_sh_br_9_PCrisps_ad;by year week Brand Brand_latinname;
proc sort data=weekly_adspend_Cat54_CPI_bc;by year week Brand Brand_latinname;
proc sort data=weekly_prices_CPI;by year week Brand Brand_latinname;
data pan_wk_sh_br_9_PCrisps_ad;
merge pan_wk_sh_br_9_PCrisps_ad(in=a) weekly_adspend_Cat54_CPI_bc weekly_prices_CPI;by year week Brand Brand_latinname;if a;
run;

proc copy in=work out=idatacn;select pan_wk_sh_br_9_PCrisps_ad;run;














/*select panelists based on selection criteria:
	have spent 70% or more of their category budget on the top 10, AND 
	have 2 times or more bought or received a gift in the initialization period AND 
	2 times or more bought in estimation period*/
/*select only relevant columns, replace missing values*/
data pre_PAN_WK_SH_BR_26112015_sel_ad;
set idatacn.pan_wk_sh_br_9_PCrisps_ad;
if rel_ttl_val_sls_top8_to_c_70=1 AND ttl_nr_shoptrips_bg_i>=2 AND ttl_nr_shoptrips_b_e>=2;
run;




/*VERY IMPORTANT! SORT BY BRAND DUMMIES SO THAT THERE'S A DIAGONAL OF ONES (MAKE SURE REFERENCE BRAND IS IN LAST COLUMN)!!!*/
proc sort data=pre_PAN_WK_SH_BR_26112015_sel_ad;by Panelist yearweekbrandinshoptrip 
descending H descending G descending F descending E descending D descending C descending B descending A;run;

data PAN_WK_SH_BR_26112015_sel_ad;
retain Panelist Vol_sls_b Vol_gift_b initialization_period_b Brand_bought Brand_gift 
rel_avg_price_per_ml_b_to_c Distr_retailer_b assort_width_b SOV_AdStock80_b_to_c 
H G F E D C B A holdout_sample;
set pre_PAN_WK_SH_BR_26112015_sel_ad;
keep Panelist Vol_sls_b Vol_gift_b initialization_period_b Brand_bought Brand_gift 
rel_avg_price_per_ml_b_to_c Distr_retailer_b assort_width_b SOV_AdStock80_b_to_c 
H G F E D C B A holdout_sample;run;






/*PREPARATION TO RUN IN MATLAB*/


/*make selection if holdout=1 & replace missigs by zero (otherwise exporting to txt does not work)*/
/*double check if #rows in dataset is equal to #shoptrips (bought or gift) * 7*/
data PAN_WK_SH_BR_26112015_sel_ho_ad;
set PAN_WK_SH_BR_26112015_sel_ad;
if holdout_sample=1;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;

proc copy in=work out=idatacn;select PAN_WK_SH_BR_26112015_sel_ho_ad;run;
/*export to text */
PROC EXPORT DATA= IDATACN.PAN_WK_SH_BR_26112015_sel_ho_ad
            OUTFILE= "\PAN_WK_SH_BR_26112015_sel_ho_ad.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;



















/*calculate most popular volume (per cat)*/

data PUR_ALLINFO_20112014_top8;
set PUR_ALLINFO_20112014;
if Brand_latinname in ("A","B","C","D","E","F","G","H");
run;

/*MOST POPULAR VOLUME SOLD*/
proc sql;
	create table vol_per_pan_ywbis as
	select Panelist, yearweekbrandinshoptrip, sum(Total_volume_sales) as Vol_sls_or_gift
	from PUR_ALLINFO_20112014_top8
	group by Panelist, yearweekbrandinshoptrip;
quit;
proc sql;
	create table nr_purocc_per_vol as
	select Vol_sls_or_gift, count(yearweekbrandinshoptrip) as nr_purocc
	from vol_per_pan_ywbis
	group by Vol_sls_or_gift;
quit;
proc sql;
	create table max_purocc_per_vol as
	select *, max(nr_purocc) as max_nr_purocc
	from nr_purocc_per_vol;
quit;
data most_pop_vol; 
set max_purocc_per_vol;
if nr_purocc=max_nr_purocc; 
Most_pop_volume=Vol_sls_or_gift;run;/*104 grams=>put in matlab*/









/*copula price*/
/*price* step 1: sort, per brand, price from low to high*/
data price_star_step1;
set idatacn.pan_wk_sh_br_9_PCrisps_ad;
keep Brand Brand_latinname BrandNumber year week period rel_avg_price_per_ml_b_to_c;
proc sort data=price_star_step1 nodup;by Brand Brand_latinname BrandNumber rel_avg_price_per_ml_b_to_c;run;

/*price* step 2: calculate H(Price) -> this is the  empirical distribution function = empirical probability that X <= x
price* step 3: calculate the inverse of the normal cumulative distribution function to get Price* */
data price_star_step23a;
set price_star_step1;
count+1;
by Brand;
if first.Brand then count=1;
run;
proc sql;
	create table price_star_step23b as 
	select *, max(count) as max_count
	from price_star_step23a
	group by Brand;
quit;
/*sort again and check whether 'ties' exist*/
proc sort data=price_star_step23b nodupkey out=price_star_step23c;by Brand Brand_latinname BrandNumber rel_avg_price_per_ml_b_to_c;run;
/*no observations are kicked out, so nu duplicate prices exist within brands across weeks*/
data price_star_step23d;
set price_star_step23c;
   ecdf_price = count / max_count;
   if ecdf_Price = 1 then ecdf_price = 0.9999999; else ecdf_price = ecdf_price;
   price_STAR= quantile('NORMAL', ecdf_price);
run;

data price_star_final;
set price_star_step23d;
keep Brand year week period price_STAR;
proc sort data=price_star_final;by Brand year week period;run;











/*then add data from PLA file*/
PROC IMPORT OUT= WORK.PRODUCTLAUNCHDATA 
            DATAFILE= "D:\Dropbox\Research\PhD projecten\Brand learning\Data\PLA_VIEWRESULTS_2020811-yixin-bve.xlsx" 
            DBMS=XLSX REPLACE;
     /*RANGE="View Results1$";*/
RUN;

/*only select top 8 brands of potato crisps*/
data PRODUCTLAUNCHDATA_pcr;
set PRODUCTLAUNCHDATA;
where market="Savory Snacks" and Brand_latinname in("A","B","C","D","E","F","G","H");
run;

proc freq data=PRODUCTLAUNCHDATA_pcr;tables what_s_new;run;
proc sort data=PRODUCTLAUNCHDATA_pcr;by brand_latinname;
proc freq data=PRODUCTLAUNCHDATA_pcr;by brand_latinname;tables Publication_date*what_s_new;run;

data inno_pcrisps_top8_pla;
set PRODUCTLAUNCHDATA_pcr;
week=week(Publication_Date);
year=year(Publication_Date);
yearweek=year*100+week;
run;
proc freq data=inno_pcrisps_top8_pla;by brand_latinname;tables yearweek*what_s_new;run;

/*create variable that 'voor elk individu bij elke gift of aankoop, de variabele weergeeft hoeveel nieuwe sku's een merk heeft bijgekregen sinds de vorige gift of aankoop van dat individu'*/
/*first sum and transpose inno file*/
proc sql;
	create table sum_inno_pla as 
	select Brand_latinname, Publication_Date, sum(__SKUs) as nr_innos_launched_pla
	from inno_pcrisps_top8_pla
	group by Brand_latinname, Publication_Date;
quit;
proc sort data=sum_inno_pla;by Publication_Date;
proc transpose data=sum_inno_pla out=sum_inno_pla_t;by Publication_Date;var nr_innos_launched_pla;id Brand_latinname;run;
data sum_inno_pla_t;
set sum_inno_pla_t;
rename Publication_Date=Date_of_purchase;
drop _NAME_;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;

/*blow up table so that every date is in the file*/
data date;
set idataCN.pan_wk_sh_br_9_PCrisps_ad;
keep date_of_purchase var;
proc sort data=date nodup;by date_of_purchase;run;

proc sort data=sum_inno_pla_t;by Date_of_purchase;
proc sort data=date;by Date_of_purchase;
data sum_inno_pla_t_date;
merge sum_inno_pla_t date;by Date_of_purchase;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;

/*create cumsums so that for every date, the total number of innos for that brand is known*/
data sum_inno_pla_t_date2;
set sum_inno_pla_t_date;
retain cumsumA cumsumB cumsumC cumsumD cumsumE cumsumF cumsumG cumsumH;
cumsumA+A;
cumsumB+B;
cumsumC+C;
cumsumD+D;
cumsumE+E;
cumsumF+F;
cumsumG+G;
cumsumH+H;
run;
data sum_inno_pla_t_date2;
set sum_inno_pla_t_date2;
drop A B C D E F G H;run;

/*merge this with purchase dates of selected panelists/
/*see creation pan_bought_gift above*/
/*merge files & from this file, calculate focal variable*/
proc sort data=pan_bought_gift;by date_of_purchase;
proc sort data=sum_inno_pla_t_date2;by date_of_purchase;
data pan_bg_inno_pla;
merge pan_bought_gift(in=a) sum_inno_pla_t_date2;by date_of_purchase;if a;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;
proc sort data=pan_bg_inno_pla;by Panelist date_of_purchase;run;
data pan_bg_inno_pla2;
set pan_bg_inno_pla;
  by Panelist;
  l_cumsumCAP=lag(cumsumCAP);
  l_cumsumLEB=lag(cumsumLEB);
  l_cumsumOIS=lag(cumsumOIS);
  l_cumsumQIA=lag(cumsumQIA);
  l_cumsumHAI=lag(cumsumHAI);
  l_cumsumLAY=lag(cumsumLAY);
  l_cumsumOR=lag(cumsumOR);
  l_cumsumPR=lag(cumsumPR);
  d_cumsumCAP=dif(cumsumCAP);
  d_cumsumLEB=dif(cumsumLEB);
  d_cumsumOIS=dif(cumsumOIS);
  d_cumsumQIA=dif(cumsumQIA);
  d_cumsumHAI=dif(cumsumHAI);
  d_cumsumLAY=dif(cumsumLAY);
  d_cumsumOR=dif(cumsumOR);
  d_cumsumPR=dif(cumsumPR);
  if first.Panelist then do;
  l_cumsumCAP=.;
  l_cumsumLEB=.;
  l_cumsumOIS=.;
  l_cumsumQIA=.;
  l_cumsumHAI=.;
  l_cumsumLAY=.;
  l_cumsumOR=.;
  l_cumsumPR=.;
  d_cumsumCAP=.;
  d_cumsumLEB=.;
  d_cumsumOIS=.;
  d_cumsumQIA=.;
  d_cumsumHAI=.;
  d_cumsumLAY=.;
  d_cumsumOR=.;
  d_cumsumPR=.;
  end;
run;
data pan_bg_inno_pla2;
set pan_bg_inno_pla2;
if year(Date_of_purchase)=2011 then do;
  if d_cumsumA=. then d_cumsumA=0;
  if d_cumsumB=. then d_cumsumB=0;
  if d_cumsumC=. then d_cumsumC=0;
  if d_cumsumD=. then d_cumsumD=0;
  if d_cumsumE=. then d_cumsumE=0;
  if d_cumsumF=. then d_cumsumF=0;
  if d_cumsumG=. then d_cumsumG=0;
  if d_cumsumH=. then d_cumsumH=0;
end;
keep Panelist date_of_purchase d_cumsumA d_cumsumB d_cumsumC d_cumsumD d_cumsumE d_cumsumF d_cumsumG d_cumsumH;run;

/*transpose back & create final columns*/
proc transpose data=pan_bg_inno_pla2 out=pan_bg_inno_pla2_t;by Panelist date_of_purchase; 
run;
data pan_bg_inno_pla2_t;
format Brand_latinname $129.;
set pan_bg_inno_pla2_t;
nr_new_SKUs_since_last_bg=COL1;
if _NAME_="d_cumsumA" then Brand_latinname="A";
if _NAME_="d_cumsumB" then Brand_latinname="B";
if _NAME_="d_cumsumC" then Brand_latinname="C";
if _NAME_="d_cumsumD" then Brand_latinname="D";
if _NAME_="d_cumsumE" then Brand_latinname="E";
if _NAME_="d_cumsumF" then Brand_latinname="F";
if _NAME_="d_cumsumG" then Brand_latinname="G";
if _NAME_="d_cumsumH" then Brand_latinname="H";
drop _NAME_ COL1;
run;


/*add these two columns to main dataset & select panelists based on selection criteria:
	have spent 70% or more of their category budget on the top 8, AND 
	have 2 times or more bought or received a gift in the initialization period AND 
	2 times or more bought in estimation period*/
/*select only relevant columns, replace missing values*/
proc sort data=idataCN.pan_wk_sh_br_9_PCrisps_ad;by Brand period year week;
data pre_PAN_WK_SH_BR_26112015_sel_ad;
merge idataCN.pan_wk_sh_br_9_PCrisps_ad(in=a) price_star_final;by Brand period year week;if a;
if rel_ttl_val_sls_top8_to_c_70=1 AND ttl_nr_shoptrips_bg_i>=2 AND ttl_nr_shoptrips_b_e>=2;
proc sort data=pre_PAN_WK_SH_BR_26112015_sel_ad;by Panelist Date_of_purchase Brand_latinname;
proc sort data=pan_bg_inno_pla2_t;by Panelist Date_of_purchase Brand_latinname;
data pre_PAN_WK_SH_BR_26112015_sel_ad;
merge pre_PAN_WK_SH_BR_26112015_sel_ad(in=a) pan_bg_inno_pla2_t;by Panelist Date_of_purchase Brand_latinname;if a;
run;

/*VERY IMPORTANT! SORT BY BRAND DUMMIES SO THAT THERE'S A DIAGONAL OF ONES (MAKE SURE REFERENCE BRAND IS IN LAST COLUMN)!!!*/
proc sort data=pre_PAN_WK_SH_BR_26112015_sel_ad;by Panelist yearweekbrandinshoptrip 
descending H descending G descending F descending E descending D descending C descending B descending A;run;

data PAN_WK_SH_BR_26112015_sel_ad;
retain Panelist Vol_sls_b Vol_gift_b initialization_period_b Brand_bought Brand_gift 
rel_avg_price_per_ml_b_to_c Distr_retailer_b assort_width_b SOV_AdStock80_b_to_c 
H G F E D C B A holdout_sample Date_of_purchase  
price_STAR nr_new_SKUs_since_last_bg;
set pre_PAN_WK_SH_BR_26112015_sel_ad;
keep Panelist Vol_sls_b Vol_gift_b initialization_period_b Brand_bought Brand_gift 
rel_avg_price_per_ml_b_to_c Distr_retailer_b assort_width_b SOV_AdStock80_b_to_c 
H G F E D C B A holdout_sample Date_of_purchase  
price_STAR nr_new_SKUs_since_last_bg;run;





/*PREPARATION TO RUN IN MATLAB*/

/*make selection if holdout=1 & replace missigs by zero (otherwise exporting to txt does not work)*/
/*double check if #rows in dataset is equal to #shoptrips (bought or gift) * 7*/
data PAN_WK_SH_BR26112015_sel_ho_ad__;
set PAN_WK_SH_BR_26112015_sel_ad;
if holdout_sample=1;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;

/*export to text*/
PROC EXPORT DATA= PAN_WK_SH_BR26112015_sel_ho_ad__
            OUTFILE= "D:\Dropbox\Research\PhD projecten\Brand learning\Code_Els_Bernadette\Salty\revision IJRM\PAN_WK_SH_BR26112015_sel_ho_ad__.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;







/*now take into account type of innovation: create 3 columns for each type of innovation*/
/*1=flavor 2=product 3=package*/
%macro type(type=,typ=,nr=);
/*create variable that 'voor elk individu bij elke gift of aankoop, de variabele weergeeft hoeveel nieuwe sku's een merk heeft bijgekregen sinds de vorige gift of aankoop van dat individu'*/
/*first sum and transpose inno file*/
proc sql;
	create table sum_inno_pla&nr as 
	select Brand_latinname, Publication_Date, sum(__SKUs) as nr_innos_launched_pla&nr
	from inno_pcrisps_top8_pla
	where what_s_new="&type."
	group by Brand_latinname, Publication_Date;
quit;
proc sort data=sum_inno_pla&nr;by Publication_Date;
proc transpose data=sum_inno_pla&nr out=sum_inno_pla&nr._t;by Publication_Date;var nr_innos_launched_pla&nr;id Brand_latinname;run;
data sum_inno_pla&nr._t;
set sum_inno_pla&nr._t;
rename Publication_Date=Date_of_purchase;
drop _NAME_;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;

/*blow up table so that every date is in the file*/
/*see creation of data.sas above*/

proc sort data=sum_inno_pla&nr._t;by Date_of_purchase;
proc sort data=date;by Date_of_purchase;
data sum_inno_pla&nr._t_date;
merge sum_inno_pla&nr._t date;by Date_of_purchase;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;

/*create cumsums so that for every date, the total number of innos for that brand is known*/
data sum_inno_pla&nr._t_date2;
set sum_inno_pla&nr._t_date;
retain cumsumA cumsumB cumsumC cumsumD cumsumE cumsumF cumsumG cumsumH;
cumsumA+A;
cumsumB+B;
cumsumC+C;
cumsumD+D;
cumsumE+E;
cumsumF+F;
cumsumG+G;
cumsumH+H;
run;
data sum_inno_pla&nr._t_date2;
set sum_inno_pla&nr._t_date2;
drop A B C D E F G H;run;

/*merge this with purchase dates of selected panelists*/
/*see creation pan_bought_gift above*/
/*merge files & from this file, calculate focal variable*/
proc sort data=pan_bought_gift;by date_of_purchase;
proc sort data=sum_inno_pla&nr._t_date2;by date_of_purchase;
data pan_bg_inno_pla&nr;
merge pan_bought_gift(in=a) sum_inno_pla&nr._t_date2;by date_of_purchase;if a;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;
proc sort data=pan_bg_inno_pla&nr;by Panelist date_of_purchase;run;
data pan_bg_inno_pla&nr.2;
set pan_bg_inno_pla&nr;
  by Panelist;
  l_cumsumA=lag(cumsumA);
  l_cumsumB=lag(cumsumB);
  l_cumsumC=lag(cumsumC);
  l_cumsumD=lag(cumsumD);
  l_cumsumE=lag(cumsumE);
  l_cumsumF=lag(cumsumF);
  l_cumsumG=lag(cumsumG);
  l_cumsumH=lag(cumsumH);
  d_cumsumA=dif(cumsumA);
  d_cumsumB=dif(cumsumB);
  d_cumsumC=dif(cumsumC);
  d_cumsumD=dif(cumsumD);
  d_cumsumE=dif(cumsumE);
  d_cumsumF=dif(cumsumF);
  d_cumsumG=dif(cumsumG);
  d_cumsumH=dif(cumsumH);
  if first.Panelist then do;
  l_cumsumA=.;
  l_cumsumB=.;
  l_cumsumC=.;
  l_cumsumD=.;
  l_cumsumE=.;
  l_cumsumF=.;
  l_cumsumG=.;
  l_cumsumH=.;
  d_cumsumA=.;
  d_cumsumB=.;
  d_cumsumC=.;
  d_cumsumD=.;
  d_cumsumE=.;
  d_cumsumF=.;
  d_cumsumG=.;
  d_cumsumH=.;
  end;
run;
data pan_bg_inno_pla&nr.2;
set pan_bg_inno_pla&nr.2;
if year(Date_of_purchase)=2011 then do;
  if d_cumsumA=. then d_cumsumA=0;
  if d_cumsumB=. then d_cumsumB=0;
  if d_cumsumC=. then d_cumsumC=0;
  if d_cumsumD=. then d_cumsumD=0;
  if d_cumsumE=. then d_cumsumE=0;
  if d_cumsumF=. then d_cumsumF=0;
  if d_cumsumG=. then d_cumsumG=0;
  if d_cumsumH=. then d_cumsumH=0;
end;
keep Panelist date_of_purchase d_cumsuma d_cumsumB d_cumsumC d_cumsumD d_cumsumE d_cumsumF d_cumsumG d_cumsumH;run;

/*transpose back & create final columns*/
proc transpose data=pan_bg_inno_pla&nr.2 out=pan_bg_inno_pla&nr.2_t;by Panelist date_of_purchase; 
run;
data pan_bg_inno_pla&nr.2_t;
format Brand_latinname $129.;
set pan_bg_inno_pla&nr.2_t;
nr_new&typ._SKUs_since_last_bg=COL1;
if _NAME_="d_cumsumA" then Brand_latinname="A";
if _NAME_="d_cumsumB" then Brand_latinname="B";
if _NAME_="d_cumsumC" then Brand_latinname="C";
if _NAME_="d_cumsumD" then Brand_latinname="D";
if _NAME_="d_cumsumE" then Brand_latinname="E";
if _NAME_="d_cumsumF" then Brand_latinname="F";
if _NAME_="d_cumsumG" then Brand_latinname="G";
if _NAME_="d_cumsumH" then Brand_latinname="H";
drop _NAME_ COL1;
run;
%mend type;
%type(type=flavor,typ=flav,nr=1);%type(type=product,typ=prod,nr=2);%type(type=package,typ=pack,nr=3);

proc sort data=pre_PAN_WK_SH_BR_26112015_sel_ad;by Panelist Date_of_purchase Brand_latinname;
proc sort data=pan_bg_inno_pla12_t;by Panelist Date_of_purchase Brand_latinname;
proc sort data=pan_bg_inno_pla22_t;by Panelist Date_of_purchase Brand_latinname;
proc sort data=pan_bg_inno_pla32_t;by Panelist Date_of_purchase Brand_latinname;
data pre_PAN_WK_SH_BR_26112015_sel_ad;
merge pre_PAN_WK_SH_BR_26112015_sel_ad(in=a) pan_bg_inno_pla12_t pan_bg_inno_pla22_t pan_bg_inno_pla32_t;by Panelist Date_of_purchase Brand_latinname;if a;
run;

/*VERY IMPORTANT! SORT BY BRAND DUMMIES SO THAT THERE'S A DIAGONAL OF ONES (MAKE SURE REFERENCE BRAND IS IN LAST COLUMN)!!!*/
proc sort data=pre_PAN_WK_SH_BR_26112015_sel_ad;by Panelist yearweekbrandinshoptrip 
descending H descending G descending F descending E descending D descending C descending B descending A;run;

data PAN_WK_SH_BR_26112015_sel_ad;
retain Panelist Vol_sls_b Vol_gift_b initialization_period_b Brand_bought Brand_gift 
rel_avg_price_per_ml_b_to_c Distr_retailer_b assort_width_b SOV_AdStock80_b_to_c  
H G F E D C B A holdout_sample Date_of_purchase  
price_STAR nr_newflav_SKUs_since_last_bg nr_newprod_SKUs_since_last_bg nr_newpack_SKUs_since_last_bg;
set pre_PAN_WK_SH_BR_26112015_sel_ad;
keep Panelist Vol_sls_b Vol_gift_b initialization_period_b Brand_bought Brand_gift 
rel_avg_price_per_ml_b_to_c Distr_retailer_b assort_width_b SOV_AdStock80_b_to_c  
H G F E D C B A holdout_sample Date_of_purchase  
price_STAR nr_newflav_SKUs_since_last_bg nr_newprod_SKUs_since_last_bg nr_newpack_SKUs_since_last_bg;run;


/*make selection if holdout=1 & replace missigs by zero (otherwise exporting to txt does not work)*/
/*double check if #rows in dataset is equal to #shoptrips (bought or gift) * 7*/
data PAN_WK_SH_BR26112015_sel_ho_ad__;
set PAN_WK_SH_BR_26112015_sel_ad;
if holdout_sample=1;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
run;

/*export to text: note saved as _R at the end!*/
PROC EXPORT DATA= PAN_WK_SH_BR26112015_sel_ho_ad__
            OUTFILE= "\PAN_WK_SH_BR26112015_sel_ho_ad_R.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;




/*change nr_new_SKUs_since_last_bg-column such that if two or more brands are bought during one shopping trip, after first brand, nr_new_SKUs equals zero*/
/*merge this with purchase dates of selected panelists & with panelist's city tier*/
data nr_new_SKUs_correct;
set idatacnp.pan_wk_sh_br_9_pcrisps_ad;
if rel_ttl_val_sls_top8_to_c_70=1 AND ttl_nr_shoptrips_bg_i>=2 AND ttl_nr_shoptrips_b_e>=2;
if holdout_sample=1;
keep panelist yearweekbrandinshoptrip H G F E D C B A;
run;

proc sort data = nr_new_SKUs_correct nodupkey out=temp;by panelist yearweekbrandinshoptrip;
run;
data temp;
set temp;by panelist;
dif_yearweekbrandinshoptrip = dif(yearweekbrandinshoptrip);
if first.panelist then
dif_yearweekbrandinshoptrip=.;
drop HAIXIN PRINGLES QIAQIA OISHI LEBA CAPICO ORION LAYS;
run;
data temp;
set temp;
if dif_yearweekbrandinshoptrip=1 then column=0;else column=1;
keep panelist yearweekbrandinshoptrip column;
proc sort data=temp;by panelist yearweekbrandinshoptrip;
proc sort data=nr_new_SKUs_correct;by panelist yearweekbrandinshoptrip;
data nr_new_SKUs_correct;
merge nr_new_SKUs_correct temp;by panelist yearweekbrandinshoptrip;
run;

/*VERY IMPORTANT! SORT BY BRAND DUMMIES SO THAT THERE'S A DIAGONAL OF ONES (MAKE SURE REFERENCE BRAND IS IN LAST COLUMN)!!!*/
proc sort data=nr_new_SKUs_correct;by Panelist yearweekbrandinshoptrip 
descending H descending G descending F descending E descending D descending C descending B descending A;run;

data nr_new_SKUs_correct;
set nr_new_SKUs_correct;
keep column;
run;

/*export to text*/
PROC EXPORT DATA= nr_new_SKUs_correct
            OUTFILE= "\nr_new_SKUs_correct.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;



/*Create copulas for mmix: price is already in main dataset, but create nevertheless to check normality and correlation*/

data vars_star_step1;
set idataCN.pan_wk_sh_br_9_PCrisps_ad;
keep Brand Brand_latinname BrandNumber year week period rel_avg_price_per_ml_b_to_c Distr_retailer_b assort_width_b SOV_AdStock80_b_to_c;
proc sort data=vars_star_step1 nodupkey;by Brand Brand_latinname BrandNumber year week period;run;

%macro cop(var=,v=);
/*price* step 1: sort, per brand, price from low to high*/
data &v._star_step1;
set vars_star_step1;
keep Brand Brand_latinname BrandNumber year week period &var;
proc sort data=&v._star_step1;by Brand Brand_latinname BrandNumber &var;run;

/*price* step 2: calculate H(Price) -> this is the  empirical distribution function = empirical probability that X <= x
price* step 3: calculate the inverse of the normal cumulative distribution function to get Price* */
data &v._star_step23a;
set &v._star_step1;
count+1;
by Brand;
if first.Brand then count=1;
run;
proc sql;
	create table &v._star_step23b as 
	select *, max(count) as ttl_count
	from &v._star_step23a
	group by Brand;
quit;
/*when 'ties' exist, give obs max of count*/
proc sql;
	create table &v._star_step23c as 
	select *, max(count) as max_count
	from &v._star_step23b
	group by Brand, Brand_latinname, BrandNumber, &var;
quit;
data &v._star_step23d;
set &v._star_step23c;
   ecdf_&v = max_count / ttl_count;
   if ecdf_&v = 1 then ecdf_&v = 0.9999999; else ecdf_&v = ecdf_&v;
   &v._STAR= quantile('NORMAL', ecdf_&v);
run;

data &v._star_final;
set &v._star_step23d;
if &var=. then &v._STAR=.;
keep Brand year week period &v._STAR;
proc sort data=&v._star_final;by Brand year week period;run;

%mend cop;
%cop(var=rel_avg_price_per_ml_b_to_c,v=price);%cop(var=Distr_retailer_b,v=distr);%cop(var=assort_width_b,v=asso);%cop(var=SOV_AdStock80_b_to_c,v=sadv);



data check;
merge vars_star_step1 price_star_final distr_star_final asso_star_final sadv_star_final;by Brand year week period;run;
proc corr data=check;var rel_avg_price_per_ml_b_to_c price_STAR Distr_retailer_b distr_STAR assort_width_b asso_STAR SOV_AdStock80_b_to_c sadv_STAR;run;
/*correlations ok*/

/*test normality of mmix instruments (so that we know whether it's ok to use copula's)*/
%macro brand(nr=);
%macro test (var=,v=);
proc capability data=check normaltest NOPRINT outtable=n_&nr._&v;
var &var;
run;

data n_&nr._&v;
retain BrandNumber;
format pval_SW $25.;
set n_&nr._&v;
BrandNumber="&nr.";
var="&var.";
_VAR__=put(_VAR_,$15.);
if _SUM_=0 then delete;/*delete brands who e.g. only have adv equal to zero*/
if _PROBN_<.05 then pval_SW='1. smaller than .05';
	else if .05<=_PROBN_<.10 then pval_SW='2. between .05 and .10';
	else if .10<=_PROBN_<.20 then pval_SW='3. between .10 and .20';
	else if _PROBN_>=.20 then pval_SW='4. greater than .20'; 
drop _VAR_;
rename _VAR__=_VAR_;
run;
%mend test;
/*%test(var=f1rlprice);*/
%test(var=rel_avg_price_per_ml_b_to_c,v=price);%test(var=Distr_retailer_b,v=distr);%test(var=assort_width_b,v=asso);%test(var=SOV_AdStock80_b_to_c,v=sadv);
%mend brand;
%brand(nr=Brand01);%brand(nr=Brand02);%brand(nr=Brand03);%brand(nr=Brand04);%brand(nr=Brand05);%brand(nr=Brand06);%brand(nr=Brand07);%brand(nr=Brand08);

data n_allbrands_allvars;
set n_:;
proc freq data=n_allbrands_allvars;tables var*pval_SW;run;
/*ok all pvalues<.05 for all brands*/

/*add copula columns price distr asso and sadv to main dataset & select panelists based on selection criteria:
	have spent 70% or more of their category budget on the top 8, AND 
	have 2 times or more bought or received a gift in the initialization period AND 
	2 times or more bought in estimation period*/
/*select only relevant columns, replace missing values*/
proc sort data=idataCN.pan_wk_sh_br_9_PCrisps_ad;by Brand year week period;
proc sort data=price_star_final;by Brand year week period;
proc sort data=distr_star_final;by Brand year week period;
proc sort data=asso_star_final;by Brand year week period;
proc sort data=sadv_star_final;by Brand year week period;
data pre_cop;
merge idataCN.pan_wk_sh_br_9_PCrisps_ad(in=a) price_star_final distr_star_final asso_star_final sadv_star_final;by Brand year week period;if a;
if rel_ttl_val_sls_top8_to_c_70=1 AND ttl_nr_shoptrips_bg_i>=2 AND ttl_nr_shoptrips_b_e>=2;
keep H G F E D C B A Panelist Brand_bought Brand_gift holdout_sample price_STAR distr_STAR asso_STAR sadv_STAR;run;
run;

/*VERY IMPORTANT! SORT BY BRAND DUMMIES SO THAT THERE'S A DIAGONAL OF ONES (MAKE SURE REFERENCE BRAND IS IN LAST COLUMN)!!!*/
proc sort data=pre_cop;by Panelist yearweekbrandinshoptrip 
descending H descending G descending F descending E descending D descending C descending B descending A;run;

data copulas;
set pre_cop;
keep Panelist Brand_bought Brand_gift holdout_sample price_STAR distr_STAR asso_STAR sadv_STAR;run;





/*make selection if holdout=1 & replace missigs by zero (otherwise exporting to txt does not work)*/
/*only keep ad_signals column*/
/*double check if #rows in dataset is equal to #shoptrips (bought or gift) * 7*/
data copulas;
set copulas;
if holdout_sample=1;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
keep price_STAR distr_STAR asso_STAR sadv_STAR;
run;
/*NOTE: There were 3030240 observations read from the data set WORK.AD_SIGNALS.
NOTE: The data set WORK.AD_SIGNALS has 747496 observations and 4 variables.
*/

/*export to text*/
PROC EXPORT DATA= copulas
            OUTFILE= "\copulas.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;



















/*adv signals*/

data ad_sig2;
set addata_cat54_wksmooth1;
ad_signal2=0;
if allmed_Gross_Adspend_b>0 then ad_signal2=1;
keep brand_latinname date_of_purchase allmed_Gross_Adspend_b ad_signal2;
run;

/*add this column to main dataset & select panelists based on selection criteria:
	have spent 70% or more of their category budget on the top 8, AND 
	have 2 times or more bought or received a gift in the initialization period AND 
	2 times or more bought in estimation period*/
/*select only relevant columns, replace missing values*/
proc sort data=idataCN.pan_wk_sh_br_9_PCrisps_ad;by Date_of_purchase Brand_latinname;
proc sort data=ad_sig2;by Date_of_purchase Brand_latinname;
data pre_adv2;
merge idataCN.pan_wk_sh_br_9_PCrisps_ad(in=a) ad_sig2;by Date_of_purchase Brand_latinname;if a;
if rel_ttl_val_sls_top8_to_c_70=1 AND ttl_nr_shoptrips_bg_i>=2 AND ttl_nr_shoptrips_b_e>=2;
run;

/*VERY IMPORTANT! SORT BY BRAND DUMMIES SO THAT THERE'S A DIAGONAL OF ONES (MAKE SURE REFERENCE BRAND IS IN LAST COLUMN)!!!*/
proc sort data=pre_adv2;by Panelist yearweekbrandinshoptrip 
descending H descending G descending F descending E descending D descending C descending B descending A;run;

data ad_signals2;
set pre_adv2;
keep Panelist Brand_bought Brand_gift holdout_sample allmed_Gross_Adspend_b ad_signal2;run;


/*make selection if holdout=1 & replace missigs by zero (otherwise exporting to txt does not work)*/
/*only keep ad_signals column*/
/*double check if #rows in dataset is equal to #shoptrips (bought or gift) * 7*/
data ad_signals2;
retain ad_signal2 allmed_Gross_Adspend_b;
set ad_signals2;
if holdout_sample=1;
   array change _numeric_;
            do over change;
            if change=. then change=0;
            end;
keep ad_signal2 allmed_Gross_Adspend_b;
run;

/*export to text*/
PROC EXPORT DATA= ad_signals
            OUTFILE= "\ad_signals.dat" 
            DBMS=TAB REPLACE;
     PUTNAMES=NO;
RUN;


/*MOST POPULAR AMOUNT SPENT*/
proc sql;
	create table am_per_date as
	select Date_of_purchase, mean(allmed_Gross_AdSpend_b) as amount_spent
	from addata_cat54_wksmooth1
	group by Date_of_purchase;
quit;
proc sql;
	create table nr_dates_per_am as
	select amount_spent, count(date_of_purchase) as nr_ad
	from am_per_date
	group by amount_spent;
quit;
proc sql;
	create table max_ad_per_am as
	select *, max(nr_ad) as max_nr_ad
	from nr_dates_per_am;
quit;
data most_pop_am; 
set max_ad_per_am;
if nr_ad=max_nr_ad; 
Most_pop_amount=amount_spent;run;/*71905410.375rmb =>put in matlab*/









